# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waMediaTransport/WAMediaTransport.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waMediaTransport/WAMediaTransport.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waCommon import WACommon_pb2 as waCommon_dot_WACommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'waMediaTransport/WAMediaTransport.proto\x12\x10WAMediaTransport\x1a\x17waCommon/WACommon.proto\"\xb3\x06\n\x10WAMediaTransport\x12=\n\x08integral\x18\x01 \x01(\x0b\x32+.WAMediaTransport.WAMediaTransport.Integral\x12?\n\tancillary\x18\x02 \x01(\x0b\x32,.WAMediaTransport.WAMediaTransport.Ancillary\x1a\xa6\x04\n\tAncillary\x12\x12\n\nfileLength\x18\x01 \x01(\x04\x12\x10\n\x08mimetype\x18\x02 \x01(\t\x12I\n\tthumbnail\x18\x03 \x01(\x0b\x32\x36.WAMediaTransport.WAMediaTransport.Ancillary.Thumbnail\x12\x10\n\x08objectID\x18\x04 \x01(\t\x1a\x95\x03\n\tThumbnail\x12\x15\n\rJPEGThumbnail\x18\x01 \x01(\x0c\x12k\n\x15\x64ownloadableThumbnail\x18\x02 \x01(\x0b\x32L.WAMediaTransport.WAMediaTransport.Ancillary.Thumbnail.DownloadableThumbnail\x12\x16\n\x0ethumbnailWidth\x18\x03 \x01(\r\x12\x17\n\x0fthumbnailHeight\x18\x04 \x01(\r\x1a\xd2\x01\n\x15\x44ownloadableThumbnail\x12\x12\n\nfileSHA256\x18\x01 \x01(\x0c\x12\x15\n\rfileEncSHA256\x18\x02 \x01(\x0c\x12\x12\n\ndirectPath\x18\x03 \x01(\t\x12\x10\n\x08mediaKey\x18\x04 \x01(\x0c\x12\x19\n\x11mediaKeyTimestamp\x18\x05 \x01(\x03\x12\x10\n\x08objectID\x18\x06 \x01(\t\x12\x1d\n\x15thumbnailScansSidecar\x18\x07 \x01(\x0c\x12\x1c\n\x14thumbnailScanLengths\x18\x08 \x03(\r\x1av\n\x08Integral\x12\x12\n\nfileSHA256\x18\x01 \x01(\x0c\x12\x10\n\x08mediaKey\x18\x02 \x01(\x0c\x12\x15\n\rfileEncSHA256\x18\x03 \x01(\x0c\x12\x12\n\ndirectPath\x18\x04 \x01(\t\x12\x19\n\x11mediaKeyTimestamp\x18\x05 \x01(\x03\"\xf5\x03\n\x0eImageTransport\x12;\n\x08integral\x18\x01 \x01(\x0b\x32).WAMediaTransport.ImageTransport.Integral\x12=\n\tancillary\x18\x02 \x01(\x0b\x32*.WAMediaTransport.ImageTransport.Ancillary\x1a\xa3\x02\n\tAncillary\x12\x0e\n\x06height\x18\x01 \x01(\r\x12\r\n\x05width\x18\x02 \x01(\r\x12\x14\n\x0cscansSidecar\x18\x03 \x01(\x0c\x12\x13\n\x0bscanLengths\x18\x04 \x03(\r\x12\x1c\n\x14midQualityFileSHA256\x18\x05 \x01(\x0c\x12\x41\n\x06hdType\x18\x06 \x01(\x0e\x32\x31.WAMediaTransport.ImageTransport.Ancillary.HdType\x12!\n\x15memoriesConceptScores\x18\x07 \x03(\x02\x42\x02\x10\x01\x12\x1e\n\x12memoriesConceptIDs\x18\x08 \x03(\rB\x02\x10\x01\"(\n\x06HdType\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05LQ_4K\x10\x01\x12\t\n\x05HQ_4K\x10\x02\x1a\x41\n\x08Integral\x12\x35\n\ttransport\x18\x01 \x01(\x0b\x32\".WAMediaTransport.WAMediaTransport\"\x84\x04\n\x0eVideoTransport\x12;\n\x08integral\x18\x01 \x01(\x0b\x32).WAMediaTransport.VideoTransport.Integral\x12=\n\tancillary\x18\x02 \x01(\x0b\x32*.WAMediaTransport.VideoTransport.Ancillary\x1a\xb2\x02\n\tAncillary\x12\x0f\n\x07seconds\x18\x01 \x01(\r\x12&\n\x07\x63\x61ption\x18\x02 \x01(\x0b\x32\x15.WACommon.MessageText\x12\x13\n\x0bgifPlayback\x18\x03 \x01(\x08\x12\x0e\n\x06height\x18\x04 \x01(\r\x12\r\n\x05width\x18\x05 \x01(\r\x12\x0f\n\x07sidecar\x18\x06 \x01(\x0c\x12N\n\x0egifAttribution\x18\x07 \x01(\x0e\x32\x36.WAMediaTransport.VideoTransport.Ancillary.Attribution\x12\x1a\n\x12\x61\x63\x63\x65ssibilityLabel\x18\x08 \x01(\t\x12\x0c\n\x04isHd\x18\t \x01(\x08\"-\n\x0b\x41ttribution\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05GIPHY\x10\x01\x12\t\n\x05TENOR\x10\x02\x1a\x41\n\x08Integral\x12\x35\n\ttransport\x18\x01 \x01(\x0b\x32\".WAMediaTransport.WAMediaTransport\"\x93\x07\n\x0e\x41udioTransport\x12;\n\x08integral\x18\x01 \x01(\x0b\x32).WAMediaTransport.AudioTransport.Integral\x12=\n\tancillary\x18\x02 \x01(\x0b\x32*.WAMediaTransport.AudioTransport.Ancillary\x1a\xce\x04\n\tAncillary\x12\x0f\n\x07seconds\x18\x01 \x01(\r\x12K\n\x0b\x61vatarAudio\x18\x02 \x01(\x0b\x32\x36.WAMediaTransport.AudioTransport.Ancillary.AvatarAudio\x1a\xe2\x03\n\x0b\x41vatarAudio\x12\x0e\n\x06poseID\x18\x01 \x01(\r\x12m\n\x10\x61vatarAnimations\x18\x02 \x03(\x0b\x32S.WAMediaTransport.AudioTransport.Ancillary.AvatarAudio.DownloadableAvatarAnimations\x1a\xfb\x01\n\x1c\x44ownloadableAvatarAnimations\x12\x12\n\nfileSHA256\x18\x01 \x01(\x0c\x12\x15\n\rfileEncSHA256\x18\x02 \x01(\x0c\x12\x12\n\ndirectPath\x18\x03 \x01(\t\x12\x10\n\x08mediaKey\x18\x04 \x01(\x0c\x12\x19\n\x11mediaKeyTimestamp\x18\x05 \x01(\x03\x12\x10\n\x08objectID\x18\x06 \x01(\t\x12]\n\x0e\x61nimationsType\x18\x07 \x01(\x0e\x32\x45.WAMediaTransport.AudioTransport.Ancillary.AvatarAudio.AnimationsType\"V\n\x0e\x41nimationsType\x12\r\n\tTALKING_A\x10\x00\x12\n\n\x06IDLE_A\x10\x01\x12\r\n\tTALKING_B\x10\x02\x12\n\n\x06IDLE_B\x10\x03\x12\x0e\n\nBACKGROUND\x10\x04\x1a\xb3\x01\n\x08Integral\x12\x35\n\ttransport\x18\x01 \x01(\x0b\x32\".WAMediaTransport.WAMediaTransport\x12J\n\x0b\x61udioFormat\x18\x02 \x01(\x0e\x32\x35.WAMediaTransport.AudioTransport.Integral.AudioFormat\"$\n\x0b\x41udioFormat\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04OPUS\x10\x01\"\xf8\x01\n\x11\x44ocumentTransport\x12>\n\x08integral\x18\x01 \x01(\x0b\x32,.WAMediaTransport.DocumentTransport.Integral\x12@\n\tancillary\x18\x02 \x01(\x0b\x32-.WAMediaTransport.DocumentTransport.Ancillary\x1a\x1e\n\tAncillary\x12\x11\n\tpageCount\x18\x01 \x01(\r\x1a\x41\n\x08Integral\x12\x35\n\ttransport\x18\x01 \x01(\x0b\x32\".WAMediaTransport.WAMediaTransport\"\xd8\x03\n\x10StickerTransport\x12=\n\x08integral\x18\x01 \x01(\x0b\x32+.WAMediaTransport.StickerTransport.Integral\x12?\n\tancillary\x18\x02 \x01(\x0b\x32,.WAMediaTransport.StickerTransport.Ancillary\x1a\xd3\x01\n\tAncillary\x12\x11\n\tpageCount\x18\x01 \x01(\r\x12\x0e\n\x06height\x18\x02 \x01(\r\x12\r\n\x05width\x18\x03 \x01(\r\x12\x18\n\x10\x66irstFrameLength\x18\x04 \x01(\r\x12\x19\n\x11\x66irstFrameSidecar\x18\x05 \x01(\x0c\x12\x14\n\x0cmustacheText\x18\x06 \x01(\t\x12\x14\n\x0cisThirdParty\x18\x07 \x01(\x08\x12\x17\n\x0freceiverFetchID\x18\x08 \x01(\t\x12\x1a\n\x12\x61\x63\x63\x65ssibilityLabel\x18\t \x01(\t\x1an\n\x08Integral\x12\x35\n\ttransport\x18\x01 \x01(\x0b\x32\".WAMediaTransport.WAMediaTransport\x12\x12\n\nisAnimated\x18\x02 \x01(\x08\x12\x17\n\x0freceiverFetchID\x18\x03 \x01(\t\"\x9d\x02\n\x10\x43ontactTransport\x12=\n\x08integral\x18\x01 \x01(\x0b\x32+.WAMediaTransport.ContactTransport.Integral\x12?\n\tancillary\x18\x02 \x01(\x0b\x32,.WAMediaTransport.ContactTransport.Ancillary\x1a \n\tAncillary\x12\x13\n\x0b\x64isplayName\x18\x01 \x01(\t\x1ag\n\x08Integral\x12\x0f\n\x05vcard\x18\x01 \x01(\tH\x00\x12?\n\x11\x64ownloadableVcard\x18\x02 \x01(\x0b\x32\".WAMediaTransport.WAMediaTransportH\x00\x42\t\n\x07\x63ontactB,Z*go.mau.fi/whatsmeow/proto/waMediaTransport')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waMediaTransport.WAMediaTransport_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z*go.mau.fi/whatsmeow/proto/waMediaTransport'
  _globals['_IMAGETRANSPORT_ANCILLARY'].fields_by_name['memoriesConceptScores']._loaded_options = None
  _globals['_IMAGETRANSPORT_ANCILLARY'].fields_by_name['memoriesConceptScores']._serialized_options = b'\020\001'
  _globals['_IMAGETRANSPORT_ANCILLARY'].fields_by_name['memoriesConceptIDs']._loaded_options = None
  _globals['_IMAGETRANSPORT_ANCILLARY'].fields_by_name['memoriesConceptIDs']._serialized_options = b'\020\001'
  _globals['_WAMEDIATRANSPORT']._serialized_start=87
  _globals['_WAMEDIATRANSPORT']._serialized_end=906
  _globals['_WAMEDIATRANSPORT_ANCILLARY']._serialized_start=236
  _globals['_WAMEDIATRANSPORT_ANCILLARY']._serialized_end=786
  _globals['_WAMEDIATRANSPORT_ANCILLARY_THUMBNAIL']._serialized_start=381
  _globals['_WAMEDIATRANSPORT_ANCILLARY_THUMBNAIL']._serialized_end=786
  _globals['_WAMEDIATRANSPORT_ANCILLARY_THUMBNAIL_DOWNLOADABLETHUMBNAIL']._serialized_start=576
  _globals['_WAMEDIATRANSPORT_ANCILLARY_THUMBNAIL_DOWNLOADABLETHUMBNAIL']._serialized_end=786
  _globals['_WAMEDIATRANSPORT_INTEGRAL']._serialized_start=788
  _globals['_WAMEDIATRANSPORT_INTEGRAL']._serialized_end=906
  _globals['_IMAGETRANSPORT']._serialized_start=909
  _globals['_IMAGETRANSPORT']._serialized_end=1410
  _globals['_IMAGETRANSPORT_ANCILLARY']._serialized_start=1052
  _globals['_IMAGETRANSPORT_ANCILLARY']._serialized_end=1343
  _globals['_IMAGETRANSPORT_ANCILLARY_HDTYPE']._serialized_start=1303
  _globals['_IMAGETRANSPORT_ANCILLARY_HDTYPE']._serialized_end=1343
  _globals['_IMAGETRANSPORT_INTEGRAL']._serialized_start=1345
  _globals['_IMAGETRANSPORT_INTEGRAL']._serialized_end=1410
  _globals['_VIDEOTRANSPORT']._serialized_start=1413
  _globals['_VIDEOTRANSPORT']._serialized_end=1929
  _globals['_VIDEOTRANSPORT_ANCILLARY']._serialized_start=1556
  _globals['_VIDEOTRANSPORT_ANCILLARY']._serialized_end=1862
  _globals['_VIDEOTRANSPORT_ANCILLARY_ATTRIBUTION']._serialized_start=1817
  _globals['_VIDEOTRANSPORT_ANCILLARY_ATTRIBUTION']._serialized_end=1862
  _globals['_VIDEOTRANSPORT_INTEGRAL']._serialized_start=1345
  _globals['_VIDEOTRANSPORT_INTEGRAL']._serialized_end=1410
  _globals['_AUDIOTRANSPORT']._serialized_start=1932
  _globals['_AUDIOTRANSPORT']._serialized_end=2847
  _globals['_AUDIOTRANSPORT_ANCILLARY']._serialized_start=2075
  _globals['_AUDIOTRANSPORT_ANCILLARY']._serialized_end=2665
  _globals['_AUDIOTRANSPORT_ANCILLARY_AVATARAUDIO']._serialized_start=2183
  _globals['_AUDIOTRANSPORT_ANCILLARY_AVATARAUDIO']._serialized_end=2665
  _globals['_AUDIOTRANSPORT_ANCILLARY_AVATARAUDIO_DOWNLOADABLEAVATARANIMATIONS']._serialized_start=2326
  _globals['_AUDIOTRANSPORT_ANCILLARY_AVATARAUDIO_DOWNLOADABLEAVATARANIMATIONS']._serialized_end=2577
  _globals['_AUDIOTRANSPORT_ANCILLARY_AVATARAUDIO_ANIMATIONSTYPE']._serialized_start=2579
  _globals['_AUDIOTRANSPORT_ANCILLARY_AVATARAUDIO_ANIMATIONSTYPE']._serialized_end=2665
  _globals['_AUDIOTRANSPORT_INTEGRAL']._serialized_start=2668
  _globals['_AUDIOTRANSPORT_INTEGRAL']._serialized_end=2847
  _globals['_AUDIOTRANSPORT_INTEGRAL_AUDIOFORMAT']._serialized_start=2811
  _globals['_AUDIOTRANSPORT_INTEGRAL_AUDIOFORMAT']._serialized_end=2847
  _globals['_DOCUMENTTRANSPORT']._serialized_start=2850
  _globals['_DOCUMENTTRANSPORT']._serialized_end=3098
  _globals['_DOCUMENTTRANSPORT_ANCILLARY']._serialized_start=3001
  _globals['_DOCUMENTTRANSPORT_ANCILLARY']._serialized_end=3031
  _globals['_DOCUMENTTRANSPORT_INTEGRAL']._serialized_start=1345
  _globals['_DOCUMENTTRANSPORT_INTEGRAL']._serialized_end=1410
  _globals['_STICKERTRANSPORT']._serialized_start=3101
  _globals['_STICKERTRANSPORT']._serialized_end=3573
  _globals['_STICKERTRANSPORT_ANCILLARY']._serialized_start=3250
  _globals['_STICKERTRANSPORT_ANCILLARY']._serialized_end=3461
  _globals['_STICKERTRANSPORT_INTEGRAL']._serialized_start=3463
  _globals['_STICKERTRANSPORT_INTEGRAL']._serialized_end=3573
  _globals['_CONTACTTRANSPORT']._serialized_start=3576
  _globals['_CONTACTTRANSPORT']._serialized_end=3861
  _globals['_CONTACTTRANSPORT_ANCILLARY']._serialized_start=3724
  _globals['_CONTACTTRANSPORT_ANCILLARY']._serialized_end=3756
  _globals['_CONTACTTRANSPORT_INTEGRAL']._serialized_start=3758
  _globals['_CONTACTTRANSPORT_INTEGRAL']._serialized_end=3861
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waSyncAction/WASyncAction.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waSyncAction/WASyncAction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waChatLockSettings import WAProtobufsChatLockSettings_pb2 as waChatLockSettings_dot_WAProtobufsChatLockSettings__pb2
from waDeviceCapabilities import WAProtobufsDeviceCapabilities_pb2 as waDeviceCapabilities_dot_WAProtobufsDeviceCapabilities__pb2
from waCommon import WACommon_pb2 as waCommon_dot_WACommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fwaSyncAction/WASyncAction.proto\x12\x0cWASyncAction\x1a\x34waChatLockSettings/WAProtobufsChatLockSettings.proto\x1a\x38waDeviceCapabilities/WAProtobufsDeviceCapabilities.proto\x1a\x17waCommon/WACommon.proto\"\xfa\x06\n\rCallLogRecord\x12:\n\ncallResult\x18\x01 \x01(\x0e\x32&.WASyncAction.CallLogRecord.CallResult\x12\x11\n\tisDndMode\x18\x02 \x01(\x08\x12@\n\rsilenceReason\x18\x03 \x01(\x0e\x32).WASyncAction.CallLogRecord.SilenceReason\x12\x10\n\x08\x64uration\x18\x04 \x01(\x03\x12\x11\n\tstartTime\x18\x05 \x01(\x03\x12\x12\n\nisIncoming\x18\x06 \x01(\x08\x12\x0f\n\x07isVideo\x18\x07 \x01(\x08\x12\x12\n\nisCallLink\x18\x08 \x01(\x08\x12\x15\n\rcallLinkToken\x18\t \x01(\t\x12\x17\n\x0fscheduledCallID\x18\n \x01(\t\x12\x0e\n\x06\x63\x61llID\x18\x0b \x01(\t\x12\x16\n\x0e\x63\x61llCreatorJID\x18\x0c \x01(\t\x12\x10\n\x08groupJID\x18\r \x01(\t\x12\x41\n\x0cparticipants\x18\x0e \x03(\x0b\x32+.WASyncAction.CallLogRecord.ParticipantInfo\x12\x36\n\x08\x63\x61llType\x18\x0f \x01(\x0e\x32$.WASyncAction.CallLogRecord.CallType\x1a^\n\x0fParticipantInfo\x12\x0f\n\x07userJID\x18\x01 \x01(\t\x12:\n\ncallResult\x18\x02 \x01(\x0e\x32&.WASyncAction.CallLogRecord.CallResult\";\n\x08\x43\x61llType\x12\x0b\n\x07REGULAR\x10\x00\x12\x12\n\x0eSCHEDULED_CALL\x10\x01\x12\x0e\n\nVOICE_CHAT\x10\x02\"F\n\rSilenceReason\x12\x08\n\x04NONE\x10\x00\x12\r\n\tSCHEDULED\x10\x01\x12\x0b\n\x07PRIVACY\x10\x02\x12\x0f\n\x0bLIGHTWEIGHT\x10\x03\"\xaf\x01\n\nCallResult\x12\r\n\tCONNECTED\x10\x00\x12\x0c\n\x08REJECTED\x10\x01\x12\r\n\tCANCELLED\x10\x02\x12\x15\n\x11\x41\x43\x43\x45PTEDELSEWHERE\x10\x03\x12\n\n\x06MISSED\x10\x04\x12\x0b\n\x07INVALID\x10\x05\x12\x0f\n\x0bUNAVAILABLE\x10\x06\x12\x0c\n\x08UPCOMING\x10\x07\x12\n\n\x06\x46\x41ILED\x10\x08\x12\r\n\tABANDONED\x10\t\x12\x0b\n\x07ONGOING\x10\n\"\x88\x02\n!NotificationActivitySettingAction\x12p\n\x1bnotificationActivitySetting\x18\x01 \x01(\x0e\x32K.WASyncAction.NotificationActivitySettingAction.NotificationActivitySetting\"q\n\x1bNotificationActivitySetting\x12\x18\n\x14\x44\x45\x46\x41ULT_ALL_MESSAGES\x10\x00\x12\x10\n\x0c\x41LL_MESSAGES\x10\x01\x12\x0e\n\nHIGHLIGHTS\x10\x02\x12\x16\n\x12\x44\x45\x46\x41ULT_HIGHLIGHTS\x10\x03\"\x8e\x01\n\x1cWaffleAccountLinkStateAction\x12N\n\tlinkState\x18\x02 \x01(\x0e\x32;.WASyncAction.WaffleAccountLinkStateAction.AccountLinkState\"\x1e\n\x10\x41\x63\x63ountLinkState\x12\n\n\x06\x41\x43TIVE\x10\x00\"\xc1\x01\n\x1cMerchantPaymentPartnerAction\x12\x41\n\x06status\x18\x01 \x02(\x0e\x32\x31.WASyncAction.MerchantPaymentPartnerAction.Status\x12\x0f\n\x07\x63ountry\x18\x02 \x02(\t\x12\x13\n\x0bgatewayName\x18\x03 \x01(\t\x12\x14\n\x0c\x63redentialID\x18\x04 \x01(\t\"\"\n\x06Status\x12\n\n\x06\x41\x43TIVE\x10\x00\x12\x0c\n\x08INACTIVE\x10\x01\"\xc5\x01\n\x0eNoteEditAction\x12\x33\n\x04type\x18\x01 \x01(\x0e\x32%.WASyncAction.NoteEditAction.NoteType\x12\x0f\n\x07\x63hatJID\x18\x02 \x01(\t\x12\x11\n\tcreatedAt\x18\x03 \x01(\x03\x12\x0f\n\x07\x64\x65leted\x18\x04 \x01(\x08\x12\x1b\n\x13unstructuredContent\x18\x05 \x01(\t\",\n\x08NoteType\x12\x10\n\x0cUNSTRUCTURED\x10\x01\x12\x0e\n\nSTRUCTURED\x10\x02\"\xb5\x01\n\x13StatusPrivacyAction\x12\x46\n\x04mode\x18\x01 \x01(\x0e\x32\x38.WASyncAction.StatusPrivacyAction.StatusDistributionMode\x12\x0f\n\x07userJID\x18\x02 \x03(\t\"E\n\x16StatusDistributionMode\x12\x0e\n\nALLOW_LIST\x10\x00\x12\r\n\tDENY_LIST\x10\x01\x12\x0c\n\x08\x43ONTACTS\x10\x02\"\x87\x02\n\x16MarketingMessageAction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12P\n\x04type\x18\x03 \x01(\x0e\x32\x42.WASyncAction.MarketingMessageAction.MarketingMessagePrototypeType\x12\x11\n\tcreatedAt\x18\x04 \x01(\x03\x12\x12\n\nlastSentAt\x18\x05 \x01(\x03\x12\x11\n\tisDeleted\x18\x06 \x01(\x08\x12\x0f\n\x07mediaID\x18\x07 \x01(\t\"1\n\x1dMarketingMessagePrototypeType\x12\x10\n\x0cPERSONALIZED\x10\x00\"\x8f\x01\n\x1bUsernameChatStartModeAction\x12N\n\rchatStartMode\x18\x01 \x01(\x0e\x32\x37.WASyncAction.UsernameChatStartModeAction.ChatStartMode\" \n\rChatStartMode\x12\x07\n\x03LID\x10\x01\x12\x06\n\x02PN\x10\x02\"\xc3\x02\n\x0fLabelEditAction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63olor\x18\x02 \x01(\x05\x12\x14\n\x0cpredefinedID\x18\x03 \x01(\x05\x12\x0f\n\x07\x64\x65leted\x18\x04 \x01(\x08\x12\x12\n\norderIndex\x18\x05 \x01(\x05\x12\x10\n\x08isActive\x18\x06 \x01(\x08\x12\x34\n\x04type\x18\x07 \x01(\x0e\x32&.WASyncAction.LabelEditAction.ListType\x12\x13\n\x0bisImmutable\x18\x08 \x01(\x08\"{\n\x08ListType\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06UNREAD\x10\x01\x12\n\n\x06GROUPS\x10\x02\x12\r\n\tFAVORITES\x10\x03\x12\x0e\n\nPREDEFINED\x10\x04\x12\n\n\x06\x43USTOM\x10\x05\x12\r\n\tCOMMUNITY\x10\x06\x12\x13\n\x0fSERVER_ASSIGNED\x10\x07\"\xba\x03\n\x0ePatchDebugData\x12\x15\n\rcurrentLthash\x18\x01 \x01(\x0c\x12\x11\n\tnewLthash\x18\x02 \x01(\x0c\x12\x14\n\x0cpatchVersion\x18\x03 \x01(\x0c\x12\x16\n\x0e\x63ollectionName\x18\x04 \x01(\x0c\x12/\n\'firstFourBytesFromAHashOfSnapshotMACKey\x18\x05 \x01(\x0c\x12\x19\n\x11newLthashSubtract\x18\x06 \x01(\x0c\x12\x11\n\tnumberAdd\x18\x07 \x01(\x05\x12\x14\n\x0cnumberRemove\x18\x08 \x01(\x05\x12\x16\n\x0enumberOverride\x18\t \x01(\x05\x12=\n\x0esenderPlatform\x18\n \x01(\x0e\x32%.WASyncAction.PatchDebugData.Platform\x12\x17\n\x0fisSenderPrimary\x18\x0b \x01(\x08\"k\n\x08Platform\x12\x0b\n\x07\x41NDROID\x10\x00\x12\x08\n\x04SMBA\x10\x01\x12\n\n\x06IPHONE\x10\x02\x12\x08\n\x04SMBI\x10\x03\x12\x07\n\x03WEB\x10\x04\x12\x07\n\x03UWP\x10\x05\x12\n\n\x06\x44\x41RWIN\x10\x06\x12\x08\n\x04IPAD\x10\x07\x12\n\n\x06WEAROS\x10\x08\"2\n\x11RecentEmojiWeight\x12\r\n\x05\x65moji\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x02\"\xc8\x1c\n\x0fSyncActionValue\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12,\n\nstarAction\x18\x02 \x01(\x0b\x32\x18.WASyncAction.StarAction\x12\x32\n\rcontactAction\x18\x03 \x01(\x0b\x32\x1b.WASyncAction.ContactAction\x12,\n\nmuteAction\x18\x04 \x01(\x0b\x32\x18.WASyncAction.MuteAction\x12*\n\tpinAction\x18\x05 \x01(\x0b\x32\x17.WASyncAction.PinAction\x12N\n\x1bsecurityNotificationSetting\x18\x06 \x01(\x0b\x32).WASyncAction.SecurityNotificationSetting\x12\x36\n\x0fpushNameSetting\x18\x07 \x01(\x0b\x32\x1d.WASyncAction.PushNameSetting\x12\x38\n\x10quickReplyAction\x18\x08 \x01(\x0b\x32\x1e.WASyncAction.QuickReplyAction\x12H\n\x18recentEmojiWeightsAction\x18\x0b \x01(\x0b\x32&.WASyncAction.RecentEmojiWeightsAction\x12\x36\n\x0flabelEditAction\x18\x0e \x01(\x0b\x32\x1d.WASyncAction.LabelEditAction\x12\x44\n\x16labelAssociationAction\x18\x0f \x01(\x0b\x32$.WASyncAction.LabelAssociationAction\x12\x32\n\rlocaleSetting\x18\x10 \x01(\x0b\x32\x1b.WASyncAction.LocaleSetting\x12:\n\x11\x61rchiveChatAction\x18\x11 \x01(\x0b\x32\x1f.WASyncAction.ArchiveChatAction\x12H\n\x18\x64\x65leteMessageForMeAction\x18\x12 \x01(\x0b\x32&.WASyncAction.DeleteMessageForMeAction\x12\x32\n\rkeyExpiration\x18\x13 \x01(\x0b\x32\x1b.WASyncAction.KeyExpiration\x12@\n\x14markChatAsReadAction\x18\x14 \x01(\x0b\x32\".WASyncAction.MarkChatAsReadAction\x12\x36\n\x0f\x63learChatAction\x18\x15 \x01(\x0b\x32\x1d.WASyncAction.ClearChatAction\x12\x38\n\x10\x64\x65leteChatAction\x18\x16 \x01(\x0b\x32\x1e.WASyncAction.DeleteChatAction\x12\x42\n\x15unarchiveChatsSetting\x18\x17 \x01(\x0b\x32#.WASyncAction.UnarchiveChatsSetting\x12\x34\n\x0eprimaryFeature\x18\x18 \x01(\x0b\x32\x1c.WASyncAction.PrimaryFeature\x12J\n\x19\x61ndroidUnsupportedActions\x18\x1a \x01(\x0b\x32\'.WASyncAction.AndroidUnsupportedActions\x12.\n\x0b\x61gentAction\x18\x1b \x01(\x0b\x32\x19.WASyncAction.AgentAction\x12<\n\x12subscriptionAction\x18\x1c \x01(\x0b\x32 .WASyncAction.SubscriptionAction\x12@\n\x14userStatusMuteAction\x18\x1d \x01(\x0b\x32\".WASyncAction.UserStatusMuteAction\x12\x38\n\x10timeFormatAction\x18\x1e \x01(\x0b\x32\x1e.WASyncAction.TimeFormatAction\x12*\n\tnuxAction\x18\x1f \x01(\x0b\x32\x17.WASyncAction.NuxAction\x12@\n\x14primaryVersionAction\x18  \x01(\x0b\x32\".WASyncAction.PrimaryVersionAction\x12\x32\n\rstickerAction\x18! \x01(\x0b\x32\x1b.WASyncAction.StickerAction\x12J\n\x19removeRecentStickerAction\x18\" \x01(\x0b\x32\'.WASyncAction.RemoveRecentStickerAction\x12:\n\x0e\x63hatAssignment\x18# \x01(\x0b\x32\".WASyncAction.ChatAssignmentAction\x12R\n\x1a\x63hatAssignmentOpenedStatus\x18$ \x01(\x0b\x32..WASyncAction.ChatAssignmentOpenedStatusAction\x12<\n\x12pnForLidChatAction\x18% \x01(\x0b\x32 .WASyncAction.PnForLidChatAction\x12\x44\n\x16marketingMessageAction\x18& \x01(\x0b\x32$.WASyncAction.MarketingMessageAction\x12V\n\x1fmarketingMessageBroadcastAction\x18\' \x01(\x0b\x32-.WASyncAction.MarketingMessageBroadcastAction\x12\x42\n\x15\x65xternalWebBetaAction\x18( \x01(\x0b\x32#.WASyncAction.ExternalWebBetaAction\x12N\n\x1bprivacySettingRelayAllCalls\x18) \x01(\x0b\x32).WASyncAction.PrivacySettingRelayAllCalls\x12\x32\n\rcallLogAction\x18* \x01(\x0b\x32\x1b.WASyncAction.CallLogAction\x12\x38\n\rstatusPrivacy\x18, \x01(\x0b\x32!.WASyncAction.StatusPrivacyAction\x12\x46\n\x17\x62otWelcomeRequestAction\x18- \x01(\x0b\x32%.WASyncAction.BotWelcomeRequestAction\x12L\n\x17\x64\x65leteIndividualCallLog\x18. \x01(\x0b\x32+.WASyncAction.DeleteIndividualCallLogAction\x12\x42\n\x15labelReorderingAction\x18/ \x01(\x0b\x32#.WASyncAction.LabelReorderingAction\x12:\n\x11paymentInfoAction\x18\x30 \x01(\x0b\x32\x1f.WASyncAction.PaymentInfoAction\x12L\n\x1a\x63ustomPaymentMethodsAction\x18\x31 \x01(\x0b\x32(.WASyncAction.CustomPaymentMethodsAction\x12\x34\n\x0elockChatAction\x18\x32 \x01(\x0b\x32\x1c.WASyncAction.LockChatAction\x12G\n\x10\x63hatLockSettings\x18\x33 \x01(\x0b\x32-.WAProtobufsChatLockSettings.ChatLockSettings\x12H\n\x18wamoUserIdentifierAction\x18\x34 \x01(\x0b\x32&.WASyncAction.WamoUserIdentifierAction\x12\x66\n\'privacySettingDisableLinkPreviewsAction\x18\x35 \x01(\x0b\x32\x35.WASyncAction.PrivacySettingDisableLinkPreviewsAction\x12M\n\x12\x64\x65viceCapabilities\x18\x36 \x01(\x0b\x32\x31.WAProtobufsDeviceCapabilities.DeviceCapabilities\x12\x34\n\x0enoteEditAction\x18\x37 \x01(\x0b\x32\x1c.WASyncAction.NoteEditAction\x12\x36\n\x0f\x66\x61voritesAction\x18\x38 \x01(\x0b\x32\x1d.WASyncAction.FavoritesAction\x12P\n\x1cmerchantPaymentPartnerAction\x18\x39 \x01(\x0b\x32*.WASyncAction.MerchantPaymentPartnerAction\x12P\n\x1cwaffleAccountLinkStateAction\x18: \x01(\x0b\x32*.WASyncAction.WaffleAccountLinkStateAction\x12H\n\x15usernameChatStartMode\x18; \x01(\x0b\x32).WASyncAction.UsernameChatStartModeAction\x12Z\n!notificationActivitySettingAction\x18< \x01(\x0b\x32/.WASyncAction.NotificationActivitySettingAction\x12\x38\n\x10lidContactAction\x18= \x01(\x0b\x32\x1e.WASyncAction.LidContactAction\x12X\n ctwaPerCustomerDataSharingAction\x18> \x01(\x0b\x32..WASyncAction.CtwaPerCustomerDataSharingAction\"O\n CtwaPerCustomerDataSharingAction\x12+\n#isCtwaPerCustomerDataSharingEnabled\x18\x01 \x01(\x08\"k\n\x10LidContactAction\x12\x10\n\x08\x66ullName\x18\x01 \x01(\t\x12\x11\n\tfirstName\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\t\x12 \n\x18saveOnPrimaryAddressbook\x18\x04 \x01(\x08\"d\n\x0f\x46\x61voritesAction\x12\x39\n\tfavorites\x18\x01 \x03(\x0b\x32&.WASyncAction.FavoritesAction.Favorite\x1a\x16\n\x08\x46\x61vorite\x12\n\n\x02ID\x18\x01 \x01(\t\"E\n\'PrivacySettingDisableLinkPreviewsAction\x12\x1a\n\x12isPreviewsDisabled\x18\x01 \x01(\x08\".\n\x18WamoUserIdentifierAction\x12\x12\n\nidentifier\x18\x01 \x01(\t\" \n\x0eLockChatAction\x12\x0e\n\x06locked\x18\x01 \x01(\x08\"]\n\x1a\x43ustomPaymentMethodsAction\x12?\n\x14\x63ustomPaymentMethods\x18\x01 \x03(\x0b\x32!.WASyncAction.CustomPaymentMethod\"\x87\x01\n\x13\x43ustomPaymentMethod\x12\x14\n\x0c\x63redentialID\x18\x01 \x02(\t\x12\x0f\n\x07\x63ountry\x18\x02 \x02(\t\x12\x0c\n\x04type\x18\x03 \x02(\t\x12;\n\x08metadata\x18\x04 \x03(\x0b\x32).WASyncAction.CustomPaymentMethodMetadata\"9\n\x1b\x43ustomPaymentMethodMetadata\x12\x0b\n\x03key\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\" \n\x11PaymentInfoAction\x12\x0b\n\x03\x63pi\x18\x01 \x01(\t\"/\n\x15LabelReorderingAction\x12\x16\n\x0esortedLabelIDs\x18\x01 \x03(\x05\"D\n\x1d\x44\x65leteIndividualCallLogAction\x12\x0f\n\x07peerJID\x18\x01 \x01(\t\x12\x12\n\nisIncoming\x18\x02 \x01(\x08\")\n\x17\x42otWelcomeRequestAction\x12\x0e\n\x06isSent\x18\x01 \x01(\x08\"C\n\rCallLogAction\x12\x32\n\rcallLogRecord\x18\x01 \x01(\x0b\x32\x1b.WASyncAction.CallLogRecord\"0\n\x1bPrivacySettingRelayAllCalls\x12\x11\n\tisEnabled\x18\x01 \x01(\x08\"(\n\x15\x45xternalWebBetaAction\x12\x0f\n\x07isOptIn\x18\x01 \x01(\x08\"7\n\x1fMarketingMessageBroadcastAction\x12\x14\n\x0crepliedCount\x18\x01 \x01(\x05\"#\n\x12PnForLidChatAction\x12\r\n\x05pnJID\x18\x01 \x01(\t\"6\n ChatAssignmentOpenedStatusAction\x12\x12\n\nchatOpened\x18\x01 \x01(\x08\"-\n\x14\x43hatAssignmentAction\x12\x15\n\rdeviceAgentID\x18\x01 \x01(\t\"\xda\x01\n\rStickerAction\x12\x0b\n\x03URL\x18\x01 \x01(\t\x12\x15\n\rfileEncSHA256\x18\x02 \x01(\x0c\x12\x10\n\x08mediaKey\x18\x03 \x01(\x0c\x12\x10\n\x08mimetype\x18\x04 \x01(\t\x12\x0e\n\x06height\x18\x05 \x01(\r\x12\r\n\x05width\x18\x06 \x01(\r\x12\x12\n\ndirectPath\x18\x07 \x01(\t\x12\x12\n\nfileLength\x18\x08 \x01(\x04\x12\x12\n\nisFavorite\x18\t \x01(\x08\x12\x14\n\x0c\x64\x65viceIDHint\x18\n \x01(\r\x12\x10\n\x08isLottie\x18\x0b \x01(\x08\"6\n\x19RemoveRecentStickerAction\x12\x19\n\x11lastStickerSentTS\x18\x01 \x01(\x03\"\'\n\x14PrimaryVersionAction\x12\x0f\n\x07version\x18\x01 \x01(\t\"!\n\tNuxAction\x12\x14\n\x0c\x61\x63knowledged\x18\x01 \x01(\x08\"9\n\x10TimeFormatAction\x12%\n\x1disTwentyFourHourFormatEnabled\x18\x01 \x01(\x08\"%\n\x14UserStatusMuteAction\x12\r\n\x05muted\x18\x01 \x01(\x08\"[\n\x12SubscriptionAction\x12\x15\n\risDeactivated\x18\x01 \x01(\x08\x12\x16\n\x0eisAutoRenewing\x18\x02 \x01(\x08\x12\x16\n\x0e\x65xpirationDate\x18\x03 \x01(\x03\"@\n\x0b\x41gentAction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x64\x65viceID\x18\x02 \x01(\x05\x12\x11\n\tisDeleted\x18\x03 \x01(\x08\",\n\x19\x41ndroidUnsupportedActions\x12\x0f\n\x07\x61llowed\x18\x01 \x01(\x08\"\x1f\n\x0ePrimaryFeature\x12\r\n\x05\x66lags\x18\x01 \x03(\t\"(\n\rKeyExpiration\x12\x17\n\x0f\x65xpiredKeyEpoch\x18\x01 \x01(\x05\"I\n\x11SyncActionMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\"\x8d\x01\n\x16SyncActionMessageRange\x12\x1c\n\x14lastMessageTimestamp\x18\x01 \x01(\x03\x12\"\n\x1alastSystemMessageTimestamp\x18\x02 \x01(\x03\x12\x31\n\x08messages\x18\x03 \x03(\x0b\x32\x1f.WASyncAction.SyncActionMessage\"/\n\x15UnarchiveChatsSetting\x12\x16\n\x0eunarchiveChats\x18\x01 \x01(\x08\"N\n\x10\x44\x65leteChatAction\x12:\n\x0cmessageRange\x18\x01 \x01(\x0b\x32$.WASyncAction.SyncActionMessageRange\"M\n\x0f\x43learChatAction\x12:\n\x0cmessageRange\x18\x01 \x01(\x0b\x32$.WASyncAction.SyncActionMessageRange\"`\n\x14MarkChatAsReadAction\x12\x0c\n\x04read\x18\x01 \x01(\x08\x12:\n\x0cmessageRange\x18\x02 \x01(\x0b\x32$.WASyncAction.SyncActionMessageRange\"I\n\x18\x44\x65leteMessageForMeAction\x12\x13\n\x0b\x64\x65leteMedia\x18\x01 \x01(\x08\x12\x18\n\x10messageTimestamp\x18\x02 \x01(\x03\"a\n\x11\x41rchiveChatAction\x12\x10\n\x08\x61rchived\x18\x01 \x01(\x08\x12:\n\x0cmessageRange\x18\x02 \x01(\x0b\x32$.WASyncAction.SyncActionMessageRange\"L\n\x18RecentEmojiWeightsAction\x12\x30\n\x07weights\x18\x01 \x03(\x0b\x32\x1f.WASyncAction.RecentEmojiWeight\")\n\x16LabelAssociationAction\x12\x0f\n\x07labeled\x18\x01 \x01(\x08\"g\n\x10QuickReplyAction\x12\x10\n\x08shortcut\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x10\n\x08keywords\x18\x03 \x03(\t\x12\r\n\x05\x63ount\x18\x04 \x01(\x05\x12\x0f\n\x07\x64\x65leted\x18\x05 \x01(\x08\"\x1f\n\rLocaleSetting\x12\x0e\n\x06locale\x18\x01 \x01(\t\"\x1f\n\x0fPushNameSetting\x12\x0c\n\x04name\x18\x01 \x01(\t\"7\n\x1bSecurityNotificationSetting\x12\x18\n\x10showNotification\x18\x01 \x01(\x08\"\x1b\n\tPinAction\x12\x0e\n\x06pinned\x18\x01 \x01(\x08\"H\n\nMuteAction\x12\r\n\x05muted\x18\x01 \x01(\x08\x12\x18\n\x10muteEndTimestamp\x18\x02 \x01(\x03\x12\x11\n\tautoMuted\x18\x03 \x01(\x08\"\x87\x01\n\rContactAction\x12\x10\n\x08\x66ullName\x18\x01 \x01(\t\x12\x11\n\tfirstName\x18\x02 \x01(\t\x12\x0e\n\x06lidJID\x18\x03 \x01(\t\x12 \n\x18saveOnPrimaryAddressbook\x18\x04 \x01(\x08\x12\r\n\x05pnJID\x18\x05 \x01(\t\x12\x10\n\x08username\x18\x06 \x01(\t\"\x1d\n\nStarAction\x12\x0f\n\x07starred\x18\x01 \x01(\x08\"o\n\x0eSyncActionData\x12\r\n\x05index\x18\x01 \x01(\x0c\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.WASyncAction.SyncActionValue\x12\x0f\n\x07padding\x18\x03 \x01(\x0c\x12\x0f\n\x07version\x18\x04 \x01(\x05\x42(Z&go.mau.fi/whatsmeow/proto/waSyncAction')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waSyncAction.WASyncAction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z&go.mau.fi/whatsmeow/proto/waSyncAction'
  _globals['_CALLLOGRECORD']._serialized_start=187
  _globals['_CALLLOGRECORD']._serialized_end=1077
  _globals['_CALLLOGRECORD_PARTICIPANTINFO']._serialized_start=672
  _globals['_CALLLOGRECORD_PARTICIPANTINFO']._serialized_end=766
  _globals['_CALLLOGRECORD_CALLTYPE']._serialized_start=768
  _globals['_CALLLOGRECORD_CALLTYPE']._serialized_end=827
  _globals['_CALLLOGRECORD_SILENCEREASON']._serialized_start=829
  _globals['_CALLLOGRECORD_SILENCEREASON']._serialized_end=899
  _globals['_CALLLOGRECORD_CALLRESULT']._serialized_start=902
  _globals['_CALLLOGRECORD_CALLRESULT']._serialized_end=1077
  _globals['_NOTIFICATIONACTIVITYSETTINGACTION']._serialized_start=1080
  _globals['_NOTIFICATIONACTIVITYSETTINGACTION']._serialized_end=1344
  _globals['_NOTIFICATIONACTIVITYSETTINGACTION_NOTIFICATIONACTIVITYSETTING']._serialized_start=1231
  _globals['_NOTIFICATIONACTIVITYSETTINGACTION_NOTIFICATIONACTIVITYSETTING']._serialized_end=1344
  _globals['_WAFFLEACCOUNTLINKSTATEACTION']._serialized_start=1347
  _globals['_WAFFLEACCOUNTLINKSTATEACTION']._serialized_end=1489
  _globals['_WAFFLEACCOUNTLINKSTATEACTION_ACCOUNTLINKSTATE']._serialized_start=1459
  _globals['_WAFFLEACCOUNTLINKSTATEACTION_ACCOUNTLINKSTATE']._serialized_end=1489
  _globals['_MERCHANTPAYMENTPARTNERACTION']._serialized_start=1492
  _globals['_MERCHANTPAYMENTPARTNERACTION']._serialized_end=1685
  _globals['_MERCHANTPAYMENTPARTNERACTION_STATUS']._serialized_start=1651
  _globals['_MERCHANTPAYMENTPARTNERACTION_STATUS']._serialized_end=1685
  _globals['_NOTEEDITACTION']._serialized_start=1688
  _globals['_NOTEEDITACTION']._serialized_end=1885
  _globals['_NOTEEDITACTION_NOTETYPE']._serialized_start=1841
  _globals['_NOTEEDITACTION_NOTETYPE']._serialized_end=1885
  _globals['_STATUSPRIVACYACTION']._serialized_start=1888
  _globals['_STATUSPRIVACYACTION']._serialized_end=2069
  _globals['_STATUSPRIVACYACTION_STATUSDISTRIBUTIONMODE']._serialized_start=2000
  _globals['_STATUSPRIVACYACTION_STATUSDISTRIBUTIONMODE']._serialized_end=2069
  _globals['_MARKETINGMESSAGEACTION']._serialized_start=2072
  _globals['_MARKETINGMESSAGEACTION']._serialized_end=2335
  _globals['_MARKETINGMESSAGEACTION_MARKETINGMESSAGEPROTOTYPETYPE']._serialized_start=2286
  _globals['_MARKETINGMESSAGEACTION_MARKETINGMESSAGEPROTOTYPETYPE']._serialized_end=2335
  _globals['_USERNAMECHATSTARTMODEACTION']._serialized_start=2338
  _globals['_USERNAMECHATSTARTMODEACTION']._serialized_end=2481
  _globals['_USERNAMECHATSTARTMODEACTION_CHATSTARTMODE']._serialized_start=2449
  _globals['_USERNAMECHATSTARTMODEACTION_CHATSTARTMODE']._serialized_end=2481
  _globals['_LABELEDITACTION']._serialized_start=2484
  _globals['_LABELEDITACTION']._serialized_end=2807
  _globals['_LABELEDITACTION_LISTTYPE']._serialized_start=2684
  _globals['_LABELEDITACTION_LISTTYPE']._serialized_end=2807
  _globals['_PATCHDEBUGDATA']._serialized_start=2810
  _globals['_PATCHDEBUGDATA']._serialized_end=3252
  _globals['_PATCHDEBUGDATA_PLATFORM']._serialized_start=3145
  _globals['_PATCHDEBUGDATA_PLATFORM']._serialized_end=3252
  _globals['_RECENTEMOJIWEIGHT']._serialized_start=3254
  _globals['_RECENTEMOJIWEIGHT']._serialized_end=3304
  _globals['_SYNCACTIONVALUE']._serialized_start=3307
  _globals['_SYNCACTIONVALUE']._serialized_end=6963
  _globals['_CTWAPERCUSTOMERDATASHARINGACTION']._serialized_start=6965
  _globals['_CTWAPERCUSTOMERDATASHARINGACTION']._serialized_end=7044
  _globals['_LIDCONTACTACTION']._serialized_start=7046
  _globals['_LIDCONTACTACTION']._serialized_end=7153
  _globals['_FAVORITESACTION']._serialized_start=7155
  _globals['_FAVORITESACTION']._serialized_end=7255
  _globals['_FAVORITESACTION_FAVORITE']._serialized_start=7233
  _globals['_FAVORITESACTION_FAVORITE']._serialized_end=7255
  _globals['_PRIVACYSETTINGDISABLELINKPREVIEWSACTION']._serialized_start=7257
  _globals['_PRIVACYSETTINGDISABLELINKPREVIEWSACTION']._serialized_end=7326
  _globals['_WAMOUSERIDENTIFIERACTION']._serialized_start=7328
  _globals['_WAMOUSERIDENTIFIERACTION']._serialized_end=7374
  _globals['_LOCKCHATACTION']._serialized_start=7376
  _globals['_LOCKCHATACTION']._serialized_end=7408
  _globals['_CUSTOMPAYMENTMETHODSACTION']._serialized_start=7410
  _globals['_CUSTOMPAYMENTMETHODSACTION']._serialized_end=7503
  _globals['_CUSTOMPAYMENTMETHOD']._serialized_start=7506
  _globals['_CUSTOMPAYMENTMETHOD']._serialized_end=7641
  _globals['_CUSTOMPAYMENTMETHODMETADATA']._serialized_start=7643
  _globals['_CUSTOMPAYMENTMETHODMETADATA']._serialized_end=7700
  _globals['_PAYMENTINFOACTION']._serialized_start=7702
  _globals['_PAYMENTINFOACTION']._serialized_end=7734
  _globals['_LABELREORDERINGACTION']._serialized_start=7736
  _globals['_LABELREORDERINGACTION']._serialized_end=7783
  _globals['_DELETEINDIVIDUALCALLLOGACTION']._serialized_start=7785
  _globals['_DELETEINDIVIDUALCALLLOGACTION']._serialized_end=7853
  _globals['_BOTWELCOMEREQUESTACTION']._serialized_start=7855
  _globals['_BOTWELCOMEREQUESTACTION']._serialized_end=7896
  _globals['_CALLLOGACTION']._serialized_start=7898
  _globals['_CALLLOGACTION']._serialized_end=7965
  _globals['_PRIVACYSETTINGRELAYALLCALLS']._serialized_start=7967
  _globals['_PRIVACYSETTINGRELAYALLCALLS']._serialized_end=8015
  _globals['_EXTERNALWEBBETAACTION']._serialized_start=8017
  _globals['_EXTERNALWEBBETAACTION']._serialized_end=8057
  _globals['_MARKETINGMESSAGEBROADCASTACTION']._serialized_start=8059
  _globals['_MARKETINGMESSAGEBROADCASTACTION']._serialized_end=8114
  _globals['_PNFORLIDCHATACTION']._serialized_start=8116
  _globals['_PNFORLIDCHATACTION']._serialized_end=8151
  _globals['_CHATASSIGNMENTOPENEDSTATUSACTION']._serialized_start=8153
  _globals['_CHATASSIGNMENTOPENEDSTATUSACTION']._serialized_end=8207
  _globals['_CHATASSIGNMENTACTION']._serialized_start=8209
  _globals['_CHATASSIGNMENTACTION']._serialized_end=8254
  _globals['_STICKERACTION']._serialized_start=8257
  _globals['_STICKERACTION']._serialized_end=8475
  _globals['_REMOVERECENTSTICKERACTION']._serialized_start=8477
  _globals['_REMOVERECENTSTICKERACTION']._serialized_end=8531
  _globals['_PRIMARYVERSIONACTION']._serialized_start=8533
  _globals['_PRIMARYVERSIONACTION']._serialized_end=8572
  _globals['_NUXACTION']._serialized_start=8574
  _globals['_NUXACTION']._serialized_end=8607
  _globals['_TIMEFORMATACTION']._serialized_start=8609
  _globals['_TIMEFORMATACTION']._serialized_end=8666
  _globals['_USERSTATUSMUTEACTION']._serialized_start=8668
  _globals['_USERSTATUSMUTEACTION']._serialized_end=8705
  _globals['_SUBSCRIPTIONACTION']._serialized_start=8707
  _globals['_SUBSCRIPTIONACTION']._serialized_end=8798
  _globals['_AGENTACTION']._serialized_start=8800
  _globals['_AGENTACTION']._serialized_end=8864
  _globals['_ANDROIDUNSUPPORTEDACTIONS']._serialized_start=8866
  _globals['_ANDROIDUNSUPPORTEDACTIONS']._serialized_end=8910
  _globals['_PRIMARYFEATURE']._serialized_start=8912
  _globals['_PRIMARYFEATURE']._serialized_end=8943
  _globals['_KEYEXPIRATION']._serialized_start=8945
  _globals['_KEYEXPIRATION']._serialized_end=8985
  _globals['_SYNCACTIONMESSAGE']._serialized_start=8987
  _globals['_SYNCACTIONMESSAGE']._serialized_end=9060
  _globals['_SYNCACTIONMESSAGERANGE']._serialized_start=9063
  _globals['_SYNCACTIONMESSAGERANGE']._serialized_end=9204
  _globals['_UNARCHIVECHATSSETTING']._serialized_start=9206
  _globals['_UNARCHIVECHATSSETTING']._serialized_end=9253
  _globals['_DELETECHATACTION']._serialized_start=9255
  _globals['_DELETECHATACTION']._serialized_end=9333
  _globals['_CLEARCHATACTION']._serialized_start=9335
  _globals['_CLEARCHATACTION']._serialized_end=9412
  _globals['_MARKCHATASREADACTION']._serialized_start=9414
  _globals['_MARKCHATASREADACTION']._serialized_end=9510
  _globals['_DELETEMESSAGEFORMEACTION']._serialized_start=9512
  _globals['_DELETEMESSAGEFORMEACTION']._serialized_end=9585
  _globals['_ARCHIVECHATACTION']._serialized_start=9587
  _globals['_ARCHIVECHATACTION']._serialized_end=9684
  _globals['_RECENTEMOJIWEIGHTSACTION']._serialized_start=9686
  _globals['_RECENTEMOJIWEIGHTSACTION']._serialized_end=9762
  _globals['_LABELASSOCIATIONACTION']._serialized_start=9764
  _globals['_LABELASSOCIATIONACTION']._serialized_end=9805
  _globals['_QUICKREPLYACTION']._serialized_start=9807
  _globals['_QUICKREPLYACTION']._serialized_end=9910
  _globals['_LOCALESETTING']._serialized_start=9912
  _globals['_LOCALESETTING']._serialized_end=9943
  _globals['_PUSHNAMESETTING']._serialized_start=9945
  _globals['_PUSHNAMESETTING']._serialized_end=9976
  _globals['_SECURITYNOTIFICATIONSETTING']._serialized_start=9978
  _globals['_SECURITYNOTIFICATIONSETTING']._serialized_end=10033
  _globals['_PINACTION']._serialized_start=10035
  _globals['_PINACTION']._serialized_end=10062
  _globals['_MUTEACTION']._serialized_start=10064
  _globals['_MUTEACTION']._serialized_end=10136
  _globals['_CONTACTACTION']._serialized_start=10139
  _globals['_CONTACTACTION']._serialized_end=10274
  _globals['_STARACTION']._serialized_start=10276
  _globals['_STARACTION']._serialized_end=10305
  _globals['_SYNCACTIONDATA']._serialized_start=10307
  _globals['_SYNCACTIONDATA']._serialized_end=10418
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waArmadilloApplication/WAArmadilloApplication.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waArmadilloApplication/WAArmadilloApplication.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waArmadilloXMA import WAArmadilloXMA_pb2 as waArmadilloXMA_dot_WAArmadilloXMA__pb2
from waCommon import WACommon_pb2 as waCommon_dot_WACommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3waArmadilloApplication/WAArmadilloApplication.proto\x12\x16WAArmadilloApplication\x1a#waArmadilloXMA/WAArmadilloXMA.proto\x1a\x17waCommon/WACommon.proto\"\xd9\x35\n\tArmadillo\x12:\n\x07payload\x18\x01 \x01(\x0b\x32).WAArmadilloApplication.Armadillo.Payload\x12<\n\x08metadata\x18\x02 \x01(\x0b\x32*.WAArmadilloApplication.Armadillo.Metadata\x1a\n\n\x08Metadata\x1a\xa9\x02\n\x07Payload\x12<\n\x07\x63ontent\x18\x01 \x01(\x0b\x32).WAArmadilloApplication.Armadillo.ContentH\x00\x12L\n\x0f\x61pplicationData\x18\x02 \x01(\x0b\x32\x31.WAArmadilloApplication.Armadillo.ApplicationDataH\x00\x12:\n\x06signal\x18\x03 \x01(\x0b\x32(.WAArmadilloApplication.Armadillo.SignalH\x00\x12K\n\x0bsubProtocol\x18\x04 \x01(\x0b\x32\x34.WAArmadilloApplication.Armadillo.SubProtocolPayloadH\x00\x42\t\n\x07payload\x1aH\n\x12SubProtocolPayload\x12\x32\n\x0b\x66utureProof\x18\x01 \x01(\x0e\x32\x1d.WACommon.FutureProofBehavior\x1a\xae\x04\n\x06Signal\x12\x63\n\x17\x65ncryptedBackupsSecrets\x18\x01 \x01(\x0b\x32@.WAArmadilloApplication.Armadillo.Signal.EncryptedBackupsSecretsH\x00\x1a\xb4\x03\n\x17\x45ncryptedBackupsSecrets\x12\x10\n\x08\x62\x61\x63kupID\x18\x01 \x01(\x04\x12\x14\n\x0cserverDataID\x18\x02 \x01(\x04\x12U\n\x05\x65poch\x18\x03 \x03(\x0b\x32\x46.WAArmadilloApplication.Armadillo.Signal.EncryptedBackupsSecrets.Epoch\x12\x1b\n\x13tempOcmfClientState\x18\x04 \x01(\x0c\x12\x16\n\x0emailboxRootKey\x18\x05 \x01(\x0c\x12 \n\x18obliviousValidationToken\x18\x06 \x01(\x0c\x1a\xc2\x01\n\x05\x45poch\x12\n\n\x02ID\x18\x01 \x01(\x04\x12\x0e\n\x06\x61nonID\x18\x02 \x01(\x0c\x12\x0f\n\x07rootKey\x18\x03 \x01(\x0c\x12\x62\n\x06status\x18\x04 \x01(\x0e\x32R.WAArmadilloApplication.Armadillo.Signal.EncryptedBackupsSecrets.Epoch.EpochStatus\"(\n\x0b\x45pochStatus\x12\x0b\n\x07\x45S_OPEN\x10\x01\x12\x0c\n\x08\x45S_CLOSE\x10\x02\x42\x08\n\x06signal\x1a\xde\x11\n\x0f\x41pplicationData\x12\x62\n\x0cmetadataSync\x18\x01 \x01(\x0b\x32J.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncNotificationH\x00\x12_\n\raiBotResponse\x18\x02 \x01(\x0b\x32\x46.WAArmadilloApplication.Armadillo.ApplicationData.AIBotResponseMessageH\x00\x12x\n\x1dmessageHistoryDocumentMessage\x18\x03 \x01(\x0b\x32O.WAArmadilloApplication.Armadillo.ApplicationData.MessageHistoryDocumentMessageH\x00\x1aH\n\x1dMessageHistoryDocumentMessage\x12\'\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x15.WACommon.SubProtocol\x1aZ\n\x14\x41IBotResponseMessage\x12\x13\n\x0bsummonToken\x18\x01 \x01(\t\x12\x13\n\x0bmessageText\x18\x02 \x01(\t\x12\x18\n\x10serializedExtras\x18\x03 \x01(\t\x1a\xdf\x0c\n\x12MetadataSyncAction\x12i\n\nchatAction\x18\x65 \x01(\x0b\x32S.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncChatActionH\x00\x12o\n\rmessageAction\x18\x66 \x01(\x0b\x32V.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncMessageActionH\x00\x12\x17\n\x0f\x61\x63tionTimestamp\x18\x01 \x01(\x03\x1a\xdd\x01\n\x11SyncMessageAction\x12\x83\x01\n\rmessageDelete\x18\x65 \x01(\x0b\x32j.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncMessageAction.ActionMessageDeleteH\x00\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x1a\x15\n\x13\x41\x63tionMessageDeleteB\x08\n\x06\x61\x63tion\x1a\xd3\x06\n\x0eSyncChatAction\x12|\n\x0b\x63hatArchive\x18\x65 \x01(\x0b\x32\x65.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction.ActionChatArchiveH\x00\x12z\n\nchatDelete\x18\x66 \x01(\x0b\x32\x64.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction.ActionChatDeleteH\x00\x12v\n\x08\x63hatRead\x18g \x01(\x0b\x32\x62.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction.ActionChatReadH\x00\x12\x0e\n\x06\x63hatID\x18\x01 \x01(\t\x1a\x91\x01\n\x0e\x41\x63tionChatRead\x12q\n\x0cmessageRange\x18\x01 \x01(\x0b\x32[.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageRange\x12\x0c\n\x04read\x18\x02 \x01(\x08\x1a\x85\x01\n\x10\x41\x63tionChatDelete\x12q\n\x0cmessageRange\x18\x01 \x01(\x0b\x32[.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageRange\x1a\x98\x01\n\x11\x41\x63tionChatArchive\x12q\n\x0cmessageRange\x18\x01 \x01(\x0b\x32[.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageRange\x12\x10\n\x08\x61rchived\x18\x02 \x01(\x08\x42\x08\n\x06\x61\x63tion\x1aI\n\x11SyncActionMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x1a\xc4\x01\n\x16SyncActionMessageRange\x12\x1c\n\x14lastMessageTimestamp\x18\x01 \x01(\x03\x12\"\n\x1alastSystemMessageTimestamp\x18\x02 \x01(\x03\x12h\n\x08messages\x18\x03 \x03(\x0b\x32V.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageB\x0c\n\nactionType\x1aq\n\x18MetadataSyncNotification\x12U\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32\x44.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncActionB\x11\n\x0f\x61pplicationData\x1a\xbd\x1b\n\x07\x43ontent\x12P\n\rcommonSticker\x18\x01 \x01(\x0b\x32\x37.WAArmadilloApplication.Armadillo.Content.CommonStickerH\x00\x12V\n\x10screenshotAction\x18\x03 \x01(\x0b\x32:.WAArmadilloApplication.Armadillo.Content.ScreenshotActionH\x00\x12H\n\x16\x65xtendedContentMessage\x18\x04 \x01(\x0b\x32&.WAArmadilloXMA.ExtendedContentMessageH\x00\x12N\n\x0cravenMessage\x18\x05 \x01(\x0b\x32\x36.WAArmadilloApplication.Armadillo.Content.RavenMessageH\x00\x12\x64\n\x17ravenActionNotifMessage\x18\x06 \x01(\x0b\x32\x41.WAArmadilloApplication.Armadillo.Content.RavenActionNotifMessageH\x00\x12r\n\x1e\x65xtendedMessageContentWithSear\x18\x07 \x01(\x0b\x32H.WAArmadilloApplication.Armadillo.Content.ExtendedContentMessageWithSearH\x00\x12\\\n\x13imageGalleryMessage\x18\x08 \x01(\x0b\x32=.WAArmadilloApplication.Armadillo.Content.ImageGalleryMessageH\x00\x12j\n\x1apaymentsTransactionMessage\x18\n \x01(\x0b\x32\x44.WAArmadilloApplication.Armadillo.Content.PaymentsTransactionMessageH\x00\x12\\\n\x13\x62umpExistingMessage\x18\x0b \x01(\x0b\x32=.WAArmadilloApplication.Armadillo.Content.BumpExistingMessageH\x00\x12V\n\x10noteReplyMessage\x18\r \x01(\x0b\x32:.WAArmadilloApplication.Armadillo.Content.NoteReplyMessageH\x00\x12R\n\x10ravenMessageMsgr\x18\x0e \x01(\x0b\x32\x36.WAArmadilloApplication.Armadillo.Content.RavenMessageH\x00\x12j\n\x1anetworkVerificationMessage\x18\x0f \x01(\x0b\x32\x44.WAArmadilloApplication.Armadillo.Content.NetworkVerificationMessageH\x00\x1a\xf2\x06\n\x1aPaymentsTransactionMessage\x12\x15\n\rtransactionID\x18\x01 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\x12\x10\n\x08\x63urrency\x18\x03 \x01(\t\x12i\n\rpaymentStatus\x18\x04 \x01(\x0e\x32R.WAArmadilloApplication.Armadillo.Content.PaymentsTransactionMessage.PaymentStatus\x12\x46\n\x16\x65xtendedContentMessage\x18\x05 \x01(\x0b\x32&.WAArmadilloXMA.ExtendedContentMessage\"\xe7\x04\n\rPaymentStatus\x12\x13\n\x0fPAYMENT_UNKNOWN\x10\x00\x12\x12\n\x0eREQUEST_INITED\x10\x04\x12\x14\n\x10REQUEST_DECLINED\x10\x05\x12\x1b\n\x17REQUEST_TRANSFER_INITED\x10\x06\x12\x1e\n\x1aREQUEST_TRANSFER_COMPLETED\x10\x07\x12\x1b\n\x17REQUEST_TRANSFER_FAILED\x10\x08\x12\x14\n\x10REQUEST_CANCELED\x10\t\x12\x13\n\x0fREQUEST_EXPIRED\x10\n\x12\x13\n\x0fTRANSFER_INITED\x10\x0b\x12\x14\n\x10TRANSFER_PENDING\x10\x0c\x12+\n\'TRANSFER_PENDING_RECIPIENT_VERIFICATION\x10\r\x12\x15\n\x11TRANSFER_CANCELED\x10\x0e\x12\x16\n\x12TRANSFER_COMPLETED\x10\x0f\x12;\n7TRANSFER_NO_RECEIVER_CREDENTIAL_NO_RTS_PENDING_CANCELED\x10\x10\x12\x38\n4TRANSFER_NO_RECEIVER_CREDENTIAL_NO_RTS_PENDING_OTHER\x10\x11\x12\x15\n\x11TRANSFER_REFUNDED\x10\x12\x12\x1b\n\x17TRANSFER_PARTIAL_REFUND\x10\x13\x12\x19\n\x15TRANSFER_CHARGED_BACK\x10\x14\x12\x14\n\x10TRANSFER_EXPIRED\x10\x15\x12\x15\n\x11TRANSFER_DECLINED\x10\x16\x12\x18\n\x14TRANSFER_UNAVAILABLE\x10\x17\x1a.\n\x1aNetworkVerificationMessage\x12\x10\n\x08\x63odeText\x18\x01 \x01(\t\x1a\x86\x02\n\x10NoteReplyMessage\x12,\n\x0btextContent\x18\x04 \x01(\x0b\x32\x15.WACommon.MessageTextH\x00\x12/\n\x0estickerContent\x18\x05 \x01(\x0b\x32\x15.WACommon.SubProtocolH\x00\x12-\n\x0cvideoContent\x18\x06 \x01(\x0b\x32\x15.WACommon.SubProtocolH\x00\x12\x0e\n\x06noteID\x18\x01 \x01(\t\x12\'\n\x08noteText\x18\x02 \x01(\x0b\x32\x15.WACommon.MessageText\x12\x17\n\x0fnoteTimestampMS\x18\x03 \x01(\x03\x42\x12\n\x10noteReplyContent\x1a\x38\n\x13\x42umpExistingMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x1a<\n\x13ImageGalleryMessage\x12%\n\x06images\x18\x01 \x03(\x0b\x32\x15.WACommon.SubProtocol\x1a\xb3\x01\n\x10ScreenshotAction\x12\x61\n\x0escreenshotType\x18\x01 \x01(\x0e\x32I.WAArmadilloApplication.Armadillo.Content.ScreenshotAction.ScreenshotType\"<\n\x0eScreenshotType\x12\x14\n\x10SCREENSHOT_IMAGE\x10\x01\x12\x14\n\x10SCREEN_RECORDING\x10\x02\x1a\xa9\x01\n\x1e\x45xtendedContentMessageWithSear\x12\x0e\n\x06searID\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x11\n\tnativeURL\x18\x03 \x01(\t\x12\x34\n\x15searAssociatedMessage\x18\x04 \x01(\x0b\x32\x15.WACommon.SubProtocol\x12\x1d\n\x15searSentWithMessageID\x18\x05 \x01(\t\x1a\xf4\x01\n\x17RavenActionNotifMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x17\n\x0f\x61\x63tionTimestamp\x18\x02 \x01(\x03\x12`\n\nactionType\x18\x03 \x01(\x0e\x32L.WAArmadilloApplication.Armadillo.Content.RavenActionNotifMessage.ActionType\";\n\nActionType\x12\n\n\x06PLAYED\x10\x00\x12\x0e\n\nSCREENSHOT\x10\x01\x12\x11\n\rFORCE_DISABLE\x10\x02\x1a\x9d\x02\n\x0cRavenMessage\x12-\n\x0cimageMessage\x18\x02 \x01(\x0b\x32\x15.WACommon.SubProtocolH\x00\x12-\n\x0cvideoMessage\x18\x03 \x01(\x0b\x32\x15.WACommon.SubProtocolH\x00\x12[\n\rephemeralType\x18\x01 \x01(\x0e\x32\x44.WAArmadilloApplication.Armadillo.Content.RavenMessage.EphemeralType\"B\n\rEphemeralType\x12\r\n\tVIEW_ONCE\x10\x00\x12\x10\n\x0c\x41LLOW_REPLAY\x10\x01\x12\x10\n\x0cKEEP_IN_CHAT\x10\x02\x42\x0e\n\x0cmediaContent\x1a\xa9\x01\n\rCommonSticker\x12X\n\x0bstickerType\x18\x01 \x01(\x0e\x32\x43.WAArmadilloApplication.Armadillo.Content.CommonSticker.StickerType\">\n\x0bStickerType\x12\x0e\n\nSMALL_LIKE\x10\x01\x12\x0f\n\x0bMEDIUM_LIKE\x10\x02\x12\x0e\n\nLARGE_LIKE\x10\x03\x42\t\n\x07\x63ontentB2Z0go.mau.fi/whatsmeow/proto/waArmadilloApplication')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waArmadilloApplication.WAArmadilloApplication_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0go.mau.fi/whatsmeow/proto/waArmadilloApplication'
  _globals['_ARMADILLO']._serialized_start=142
  _globals['_ARMADILLO']._serialized_end=7015
  _globals['_ARMADILLO_METADATA']._serialized_start=277
  _globals['_ARMADILLO_METADATA']._serialized_end=287
  _globals['_ARMADILLO_PAYLOAD']._serialized_start=290
  _globals['_ARMADILLO_PAYLOAD']._serialized_end=587
  _globals['_ARMADILLO_SUBPROTOCOLPAYLOAD']._serialized_start=589
  _globals['_ARMADILLO_SUBPROTOCOLPAYLOAD']._serialized_end=661
  _globals['_ARMADILLO_SIGNAL']._serialized_start=664
  _globals['_ARMADILLO_SIGNAL']._serialized_end=1222
  _globals['_ARMADILLO_SIGNAL_ENCRYPTEDBACKUPSSECRETS']._serialized_start=776
  _globals['_ARMADILLO_SIGNAL_ENCRYPTEDBACKUPSSECRETS']._serialized_end=1212
  _globals['_ARMADILLO_SIGNAL_ENCRYPTEDBACKUPSSECRETS_EPOCH']._serialized_start=1018
  _globals['_ARMADILLO_SIGNAL_ENCRYPTEDBACKUPSSECRETS_EPOCH']._serialized_end=1212
  _globals['_ARMADILLO_SIGNAL_ENCRYPTEDBACKUPSSECRETS_EPOCH_EPOCHSTATUS']._serialized_start=1172
  _globals['_ARMADILLO_SIGNAL_ENCRYPTEDBACKUPSSECRETS_EPOCH_EPOCHSTATUS']._serialized_end=1212
  _globals['_ARMADILLO_APPLICATIONDATA']._serialized_start=1225
  _globals['_ARMADILLO_APPLICATIONDATA']._serialized_end=3495
  _globals['_ARMADILLO_APPLICATIONDATA_MESSAGEHISTORYDOCUMENTMESSAGE']._serialized_start=1563
  _globals['_ARMADILLO_APPLICATIONDATA_MESSAGEHISTORYDOCUMENTMESSAGE']._serialized_end=1635
  _globals['_ARMADILLO_APPLICATIONDATA_AIBOTRESPONSEMESSAGE']._serialized_start=1637
  _globals['_ARMADILLO_APPLICATIONDATA_AIBOTRESPONSEMESSAGE']._serialized_end=1727
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION']._serialized_start=1730
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION']._serialized_end=3361
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCMESSAGEACTION']._serialized_start=1998
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCMESSAGEACTION']._serialized_end=2219
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCMESSAGEACTION_ACTIONMESSAGEDELETE']._serialized_start=2188
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCMESSAGEACTION_ACTIONMESSAGEDELETE']._serialized_end=2209
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCCHATACTION']._serialized_start=2222
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCCHATACTION']._serialized_end=3073
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCCHATACTION_ACTIONCHATREAD']._serialized_start=2627
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCCHATACTION_ACTIONCHATREAD']._serialized_end=2772
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCCHATACTION_ACTIONCHATDELETE']._serialized_start=2775
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCCHATACTION_ACTIONCHATDELETE']._serialized_end=2908
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCCHATACTION_ACTIONCHATARCHIVE']._serialized_start=2911
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCCHATACTION_ACTIONCHATARCHIVE']._serialized_end=3063
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCACTIONMESSAGE']._serialized_start=3075
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCACTIONMESSAGE']._serialized_end=3148
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCACTIONMESSAGERANGE']._serialized_start=3151
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCACTIONMESSAGERANGE']._serialized_end=3347
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCNOTIFICATION']._serialized_start=3363
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCNOTIFICATION']._serialized_end=3476
  _globals['_ARMADILLO_CONTENT']._serialized_start=3498
  _globals['_ARMADILLO_CONTENT']._serialized_end=7015
  _globals['_ARMADILLO_CONTENT_PAYMENTSTRANSACTIONMESSAGE']._serialized_start=4628
  _globals['_ARMADILLO_CONTENT_PAYMENTSTRANSACTIONMESSAGE']._serialized_end=5510
  _globals['_ARMADILLO_CONTENT_PAYMENTSTRANSACTIONMESSAGE_PAYMENTSTATUS']._serialized_start=4895
  _globals['_ARMADILLO_CONTENT_PAYMENTSTRANSACTIONMESSAGE_PAYMENTSTATUS']._serialized_end=5510
  _globals['_ARMADILLO_CONTENT_NETWORKVERIFICATIONMESSAGE']._serialized_start=5512
  _globals['_ARMADILLO_CONTENT_NETWORKVERIFICATIONMESSAGE']._serialized_end=5558
  _globals['_ARMADILLO_CONTENT_NOTEREPLYMESSAGE']._serialized_start=5561
  _globals['_ARMADILLO_CONTENT_NOTEREPLYMESSAGE']._serialized_end=5823
  _globals['_ARMADILLO_CONTENT_BUMPEXISTINGMESSAGE']._serialized_start=5825
  _globals['_ARMADILLO_CONTENT_BUMPEXISTINGMESSAGE']._serialized_end=5881
  _globals['_ARMADILLO_CONTENT_IMAGEGALLERYMESSAGE']._serialized_start=5883
  _globals['_ARMADILLO_CONTENT_IMAGEGALLERYMESSAGE']._serialized_end=5943
  _globals['_ARMADILLO_CONTENT_SCREENSHOTACTION']._serialized_start=5946
  _globals['_ARMADILLO_CONTENT_SCREENSHOTACTION']._serialized_end=6125
  _globals['_ARMADILLO_CONTENT_SCREENSHOTACTION_SCREENSHOTTYPE']._serialized_start=6065
  _globals['_ARMADILLO_CONTENT_SCREENSHOTACTION_SCREENSHOTTYPE']._serialized_end=6125
  _globals['_ARMADILLO_CONTENT_EXTENDEDCONTENTMESSAGEWITHSEAR']._serialized_start=6128
  _globals['_ARMADILLO_CONTENT_EXTENDEDCONTENTMESSAGEWITHSEAR']._serialized_end=6297
  _globals['_ARMADILLO_CONTENT_RAVENACTIONNOTIFMESSAGE']._serialized_start=6300
  _globals['_ARMADILLO_CONTENT_RAVENACTIONNOTIFMESSAGE']._serialized_end=6544
  _globals['_ARMADILLO_CONTENT_RAVENACTIONNOTIFMESSAGE_ACTIONTYPE']._serialized_start=6485
  _globals['_ARMADILLO_CONTENT_RAVENACTIONNOTIFMESSAGE_ACTIONTYPE']._serialized_end=6544
  _globals['_ARMADILLO_CONTENT_RAVENMESSAGE']._serialized_start=6547
  _globals['_ARMADILLO_CONTENT_RAVENMESSAGE']._serialized_end=6832
  _globals['_ARMADILLO_CONTENT_RAVENMESSAGE_EPHEMERALTYPE']._serialized_start=6750
  _globals['_ARMADILLO_CONTENT_RAVENMESSAGE_EPHEMERALTYPE']._serialized_end=6816
  _globals['_ARMADILLO_CONTENT_COMMONSTICKER']._serialized_start=6835
  _globals['_ARMADILLO_CONTENT_COMMONSTICKER']._serialized_end=7004
  _globals['_ARMADILLO_CONTENT_COMMONSTICKER_STICKERTYPE']._serialized_start=6942
  _globals['_ARMADILLO_CONTENT_COMMONSTICKER_STICKERTYPE']._serialized_end=7004
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import waArmadilloXMA.WAArmadilloXMA_pb2
import waCommon.WACommon_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Armadillo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Metadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class Payload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CONTENT_FIELD_NUMBER: builtins.int
        APPLICATIONDATA_FIELD_NUMBER: builtins.int
        SIGNAL_FIELD_NUMBER: builtins.int
        SUBPROTOCOL_FIELD_NUMBER: builtins.int
        @property
        def content(self) -> global___Armadillo.Content: ...
        @property
        def applicationData(self) -> global___Armadillo.ApplicationData: ...
        @property
        def signal(self) -> global___Armadillo.Signal: ...
        @property
        def subProtocol(self) -> global___Armadillo.SubProtocolPayload: ...
        def __init__(
            self,
            *,
            content: global___Armadillo.Content | None = ...,
            applicationData: global___Armadillo.ApplicationData | None = ...,
            signal: global___Armadillo.Signal | None = ...,
            subProtocol: global___Armadillo.SubProtocolPayload | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["applicationData", b"applicationData", "content", b"content", "payload", b"payload", "signal", b"signal", "subProtocol", b"subProtocol"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["applicationData", b"applicationData", "content", b"content", "payload", b"payload", "signal", b"signal", "subProtocol", b"subProtocol"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["payload", b"payload"]) -> typing.Literal["content", "applicationData", "signal", "subProtocol"] | None: ...

    @typing.final
    class SubProtocolPayload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FUTUREPROOF_FIELD_NUMBER: builtins.int
        futureProof: waCommon.WACommon_pb2.FutureProofBehavior.ValueType
        def __init__(
            self,
            *,
            futureProof: waCommon.WACommon_pb2.FutureProofBehavior.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["futureProof", b"futureProof"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["futureProof", b"futureProof"]) -> None: ...

    @typing.final
    class Signal(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class EncryptedBackupsSecrets(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            @typing.final
            class Epoch(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                class _EpochStatus:
                    ValueType = typing.NewType("ValueType", builtins.int)
                    V: typing_extensions.TypeAlias = ValueType

                class _EpochStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Armadillo.Signal.EncryptedBackupsSecrets.Epoch._EpochStatus.ValueType], builtins.type):
                    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                    ES_OPEN: Armadillo.Signal.EncryptedBackupsSecrets.Epoch._EpochStatus.ValueType  # 1
                    ES_CLOSE: Armadillo.Signal.EncryptedBackupsSecrets.Epoch._EpochStatus.ValueType  # 2

                class EpochStatus(_EpochStatus, metaclass=_EpochStatusEnumTypeWrapper): ...
                ES_OPEN: Armadillo.Signal.EncryptedBackupsSecrets.Epoch.EpochStatus.ValueType  # 1
                ES_CLOSE: Armadillo.Signal.EncryptedBackupsSecrets.Epoch.EpochStatus.ValueType  # 2

                ID_FIELD_NUMBER: builtins.int
                ANONID_FIELD_NUMBER: builtins.int
                ROOTKEY_FIELD_NUMBER: builtins.int
                STATUS_FIELD_NUMBER: builtins.int
                ID: builtins.int
                anonID: builtins.bytes
                rootKey: builtins.bytes
                status: global___Armadillo.Signal.EncryptedBackupsSecrets.Epoch.EpochStatus.ValueType
                def __init__(
                    self,
                    *,
                    ID: builtins.int | None = ...,
                    anonID: builtins.bytes | None = ...,
                    rootKey: builtins.bytes | None = ...,
                    status: global___Armadillo.Signal.EncryptedBackupsSecrets.Epoch.EpochStatus.ValueType | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["ID", b"ID", "anonID", b"anonID", "rootKey", b"rootKey", "status", b"status"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["ID", b"ID", "anonID", b"anonID", "rootKey", b"rootKey", "status", b"status"]) -> None: ...

            BACKUPID_FIELD_NUMBER: builtins.int
            SERVERDATAID_FIELD_NUMBER: builtins.int
            EPOCH_FIELD_NUMBER: builtins.int
            TEMPOCMFCLIENTSTATE_FIELD_NUMBER: builtins.int
            MAILBOXROOTKEY_FIELD_NUMBER: builtins.int
            OBLIVIOUSVALIDATIONTOKEN_FIELD_NUMBER: builtins.int
            backupID: builtins.int
            serverDataID: builtins.int
            tempOcmfClientState: builtins.bytes
            mailboxRootKey: builtins.bytes
            obliviousValidationToken: builtins.bytes
            @property
            def epoch(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Armadillo.Signal.EncryptedBackupsSecrets.Epoch]: ...
            def __init__(
                self,
                *,
                backupID: builtins.int | None = ...,
                serverDataID: builtins.int | None = ...,
                epoch: collections.abc.Iterable[global___Armadillo.Signal.EncryptedBackupsSecrets.Epoch] | None = ...,
                tempOcmfClientState: builtins.bytes | None = ...,
                mailboxRootKey: builtins.bytes | None = ...,
                obliviousValidationToken: builtins.bytes | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["backupID", b"backupID", "mailboxRootKey", b"mailboxRootKey", "obliviousValidationToken", b"obliviousValidationToken", "serverDataID", b"serverDataID", "tempOcmfClientState", b"tempOcmfClientState"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["backupID", b"backupID", "epoch", b"epoch", "mailboxRootKey", b"mailboxRootKey", "obliviousValidationToken", b"obliviousValidationToken", "serverDataID", b"serverDataID", "tempOcmfClientState", b"tempOcmfClientState"]) -> None: ...

        ENCRYPTEDBACKUPSSECRETS_FIELD_NUMBER: builtins.int
        @property
        def encryptedBackupsSecrets(self) -> global___Armadillo.Signal.EncryptedBackupsSecrets: ...
        def __init__(
            self,
            *,
            encryptedBackupsSecrets: global___Armadillo.Signal.EncryptedBackupsSecrets | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["encryptedBackupsSecrets", b"encryptedBackupsSecrets", "signal", b"signal"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["encryptedBackupsSecrets", b"encryptedBackupsSecrets", "signal", b"signal"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["signal", b"signal"]) -> typing.Literal["encryptedBackupsSecrets"] | None: ...

    @typing.final
    class ApplicationData(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class MessageHistoryDocumentMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            DOCUMENT_FIELD_NUMBER: builtins.int
            @property
            def document(self) -> waCommon.WACommon_pb2.SubProtocol: ...
            def __init__(
                self,
                *,
                document: waCommon.WACommon_pb2.SubProtocol | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["document", b"document"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["document", b"document"]) -> None: ...

        @typing.final
        class AIBotResponseMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            SUMMONTOKEN_FIELD_NUMBER: builtins.int
            MESSAGETEXT_FIELD_NUMBER: builtins.int
            SERIALIZEDEXTRAS_FIELD_NUMBER: builtins.int
            summonToken: builtins.str
            messageText: builtins.str
            serializedExtras: builtins.str
            def __init__(
                self,
                *,
                summonToken: builtins.str | None = ...,
                messageText: builtins.str | None = ...,
                serializedExtras: builtins.str | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["messageText", b"messageText", "serializedExtras", b"serializedExtras", "summonToken", b"summonToken"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["messageText", b"messageText", "serializedExtras", b"serializedExtras", "summonToken", b"summonToken"]) -> None: ...

        @typing.final
        class MetadataSyncAction(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            @typing.final
            class SyncMessageAction(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                @typing.final
                class ActionMessageDelete(google.protobuf.message.Message):
                    DESCRIPTOR: google.protobuf.descriptor.Descriptor

                    def __init__(
                        self,
                    ) -> None: ...

                MESSAGEDELETE_FIELD_NUMBER: builtins.int
                KEY_FIELD_NUMBER: builtins.int
                @property
                def messageDelete(self) -> global___Armadillo.ApplicationData.MetadataSyncAction.SyncMessageAction.ActionMessageDelete: ...
                @property
                def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
                def __init__(
                    self,
                    *,
                    messageDelete: global___Armadillo.ApplicationData.MetadataSyncAction.SyncMessageAction.ActionMessageDelete | None = ...,
                    key: waCommon.WACommon_pb2.MessageKey | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["action", b"action", "key", b"key", "messageDelete", b"messageDelete"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["action", b"action", "key", b"key", "messageDelete", b"messageDelete"]) -> None: ...
                def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["messageDelete"] | None: ...

            @typing.final
            class SyncChatAction(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                @typing.final
                class ActionChatRead(google.protobuf.message.Message):
                    DESCRIPTOR: google.protobuf.descriptor.Descriptor

                    MESSAGERANGE_FIELD_NUMBER: builtins.int
                    READ_FIELD_NUMBER: builtins.int
                    read: builtins.bool
                    @property
                    def messageRange(self) -> global___Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageRange: ...
                    def __init__(
                        self,
                        *,
                        messageRange: global___Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageRange | None = ...,
                        read: builtins.bool | None = ...,
                    ) -> None: ...
                    def HasField(self, field_name: typing.Literal["messageRange", b"messageRange", "read", b"read"]) -> builtins.bool: ...
                    def ClearField(self, field_name: typing.Literal["messageRange", b"messageRange", "read", b"read"]) -> None: ...

                @typing.final
                class ActionChatDelete(google.protobuf.message.Message):
                    DESCRIPTOR: google.protobuf.descriptor.Descriptor

                    MESSAGERANGE_FIELD_NUMBER: builtins.int
                    @property
                    def messageRange(self) -> global___Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageRange: ...
                    def __init__(
                        self,
                        *,
                        messageRange: global___Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageRange | None = ...,
                    ) -> None: ...
                    def HasField(self, field_name: typing.Literal["messageRange", b"messageRange"]) -> builtins.bool: ...
                    def ClearField(self, field_name: typing.Literal["messageRange", b"messageRange"]) -> None: ...

                @typing.final
                class ActionChatArchive(google.protobuf.message.Message):
                    DESCRIPTOR: google.protobuf.descriptor.Descriptor

                    MESSAGERANGE_FIELD_NUMBER: builtins.int
                    ARCHIVED_FIELD_NUMBER: builtins.int
                    archived: builtins.bool
                    @property
                    def messageRange(self) -> global___Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageRange: ...
                    def __init__(
                        self,
                        *,
                        messageRange: global___Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageRange | None = ...,
                        archived: builtins.bool | None = ...,
                    ) -> None: ...
                    def HasField(self, field_name: typing.Literal["archived", b"archived", "messageRange", b"messageRange"]) -> builtins.bool: ...
                    def ClearField(self, field_name: typing.Literal["archived", b"archived", "messageRange", b"messageRange"]) -> None: ...

                CHATARCHIVE_FIELD_NUMBER: builtins.int
                CHATDELETE_FIELD_NUMBER: builtins.int
                CHATREAD_FIELD_NUMBER: builtins.int
                CHATID_FIELD_NUMBER: builtins.int
                chatID: builtins.str
                @property
                def chatArchive(self) -> global___Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction.ActionChatArchive: ...
                @property
                def chatDelete(self) -> global___Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction.ActionChatDelete: ...
                @property
                def chatRead(self) -> global___Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction.ActionChatRead: ...
                def __init__(
                    self,
                    *,
                    chatArchive: global___Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction.ActionChatArchive | None = ...,
                    chatDelete: global___Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction.ActionChatDelete | None = ...,
                    chatRead: global___Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction.ActionChatRead | None = ...,
                    chatID: builtins.str | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["action", b"action", "chatArchive", b"chatArchive", "chatDelete", b"chatDelete", "chatID", b"chatID", "chatRead", b"chatRead"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["action", b"action", "chatArchive", b"chatArchive", "chatDelete", b"chatDelete", "chatID", b"chatID", "chatRead", b"chatRead"]) -> None: ...
                def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["chatArchive", "chatDelete", "chatRead"] | None: ...

            @typing.final
            class SyncActionMessage(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                KEY_FIELD_NUMBER: builtins.int
                TIMESTAMP_FIELD_NUMBER: builtins.int
                timestamp: builtins.int
                @property
                def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
                def __init__(
                    self,
                    *,
                    key: waCommon.WACommon_pb2.MessageKey | None = ...,
                    timestamp: builtins.int | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["key", b"key", "timestamp", b"timestamp"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["key", b"key", "timestamp", b"timestamp"]) -> None: ...

            @typing.final
            class SyncActionMessageRange(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                LASTMESSAGETIMESTAMP_FIELD_NUMBER: builtins.int
                LASTSYSTEMMESSAGETIMESTAMP_FIELD_NUMBER: builtins.int
                MESSAGES_FIELD_NUMBER: builtins.int
                lastMessageTimestamp: builtins.int
                lastSystemMessageTimestamp: builtins.int
                @property
                def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessage]: ...
                def __init__(
                    self,
                    *,
                    lastMessageTimestamp: builtins.int | None = ...,
                    lastSystemMessageTimestamp: builtins.int | None = ...,
                    messages: collections.abc.Iterable[global___Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessage] | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["lastMessageTimestamp", b"lastMessageTimestamp", "lastSystemMessageTimestamp", b"lastSystemMessageTimestamp"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["lastMessageTimestamp", b"lastMessageTimestamp", "lastSystemMessageTimestamp", b"lastSystemMessageTimestamp", "messages", b"messages"]) -> None: ...

            CHATACTION_FIELD_NUMBER: builtins.int
            MESSAGEACTION_FIELD_NUMBER: builtins.int
            ACTIONTIMESTAMP_FIELD_NUMBER: builtins.int
            actionTimestamp: builtins.int
            @property
            def chatAction(self) -> global___Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction: ...
            @property
            def messageAction(self) -> global___Armadillo.ApplicationData.MetadataSyncAction.SyncMessageAction: ...
            def __init__(
                self,
                *,
                chatAction: global___Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction | None = ...,
                messageAction: global___Armadillo.ApplicationData.MetadataSyncAction.SyncMessageAction | None = ...,
                actionTimestamp: builtins.int | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["actionTimestamp", b"actionTimestamp", "actionType", b"actionType", "chatAction", b"chatAction", "messageAction", b"messageAction"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["actionTimestamp", b"actionTimestamp", "actionType", b"actionType", "chatAction", b"chatAction", "messageAction", b"messageAction"]) -> None: ...
            def WhichOneof(self, oneof_group: typing.Literal["actionType", b"actionType"]) -> typing.Literal["chatAction", "messageAction"] | None: ...

        @typing.final
        class MetadataSyncNotification(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            ACTIONS_FIELD_NUMBER: builtins.int
            @property
            def actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Armadillo.ApplicationData.MetadataSyncAction]: ...
            def __init__(
                self,
                *,
                actions: collections.abc.Iterable[global___Armadillo.ApplicationData.MetadataSyncAction] | None = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["actions", b"actions"]) -> None: ...

        METADATASYNC_FIELD_NUMBER: builtins.int
        AIBOTRESPONSE_FIELD_NUMBER: builtins.int
        MESSAGEHISTORYDOCUMENTMESSAGE_FIELD_NUMBER: builtins.int
        @property
        def metadataSync(self) -> global___Armadillo.ApplicationData.MetadataSyncNotification: ...
        @property
        def aiBotResponse(self) -> global___Armadillo.ApplicationData.AIBotResponseMessage: ...
        @property
        def messageHistoryDocumentMessage(self) -> global___Armadillo.ApplicationData.MessageHistoryDocumentMessage: ...
        def __init__(
            self,
            *,
            metadataSync: global___Armadillo.ApplicationData.MetadataSyncNotification | None = ...,
            aiBotResponse: global___Armadillo.ApplicationData.AIBotResponseMessage | None = ...,
            messageHistoryDocumentMessage: global___Armadillo.ApplicationData.MessageHistoryDocumentMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["aiBotResponse", b"aiBotResponse", "applicationData", b"applicationData", "messageHistoryDocumentMessage", b"messageHistoryDocumentMessage", "metadataSync", b"metadataSync"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["aiBotResponse", b"aiBotResponse", "applicationData", b"applicationData", "messageHistoryDocumentMessage", b"messageHistoryDocumentMessage", "metadataSync", b"metadataSync"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["applicationData", b"applicationData"]) -> typing.Literal["metadataSync", "aiBotResponse", "messageHistoryDocumentMessage"] | None: ...

    @typing.final
    class Content(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class PaymentsTransactionMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _PaymentStatus:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _PaymentStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                PAYMENT_UNKNOWN: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 0
                REQUEST_INITED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 4
                REQUEST_DECLINED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 5
                REQUEST_TRANSFER_INITED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 6
                REQUEST_TRANSFER_COMPLETED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 7
                REQUEST_TRANSFER_FAILED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 8
                REQUEST_CANCELED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 9
                REQUEST_EXPIRED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 10
                TRANSFER_INITED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 11
                TRANSFER_PENDING: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 12
                TRANSFER_PENDING_RECIPIENT_VERIFICATION: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 13
                TRANSFER_CANCELED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 14
                TRANSFER_COMPLETED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 15
                TRANSFER_NO_RECEIVER_CREDENTIAL_NO_RTS_PENDING_CANCELED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 16
                TRANSFER_NO_RECEIVER_CREDENTIAL_NO_RTS_PENDING_OTHER: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 17
                TRANSFER_REFUNDED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 18
                TRANSFER_PARTIAL_REFUND: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 19
                TRANSFER_CHARGED_BACK: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 20
                TRANSFER_EXPIRED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 21
                TRANSFER_DECLINED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 22
                TRANSFER_UNAVAILABLE: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 23

            class PaymentStatus(_PaymentStatus, metaclass=_PaymentStatusEnumTypeWrapper): ...
            PAYMENT_UNKNOWN: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 0
            REQUEST_INITED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 4
            REQUEST_DECLINED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 5
            REQUEST_TRANSFER_INITED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 6
            REQUEST_TRANSFER_COMPLETED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 7
            REQUEST_TRANSFER_FAILED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 8
            REQUEST_CANCELED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 9
            REQUEST_EXPIRED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 10
            TRANSFER_INITED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 11
            TRANSFER_PENDING: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 12
            TRANSFER_PENDING_RECIPIENT_VERIFICATION: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 13
            TRANSFER_CANCELED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 14
            TRANSFER_COMPLETED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 15
            TRANSFER_NO_RECEIVER_CREDENTIAL_NO_RTS_PENDING_CANCELED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 16
            TRANSFER_NO_RECEIVER_CREDENTIAL_NO_RTS_PENDING_OTHER: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 17
            TRANSFER_REFUNDED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 18
            TRANSFER_PARTIAL_REFUND: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 19
            TRANSFER_CHARGED_BACK: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 20
            TRANSFER_EXPIRED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 21
            TRANSFER_DECLINED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 22
            TRANSFER_UNAVAILABLE: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 23

            TRANSACTIONID_FIELD_NUMBER: builtins.int
            AMOUNT_FIELD_NUMBER: builtins.int
            CURRENCY_FIELD_NUMBER: builtins.int
            PAYMENTSTATUS_FIELD_NUMBER: builtins.int
            EXTENDEDCONTENTMESSAGE_FIELD_NUMBER: builtins.int
            transactionID: builtins.int
            amount: builtins.str
            currency: builtins.str
            paymentStatus: global___Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType
            @property
            def extendedContentMessage(self) -> waArmadilloXMA.WAArmadilloXMA_pb2.ExtendedContentMessage: ...
            def __init__(
                self,
                *,
                transactionID: builtins.int | None = ...,
                amount: builtins.str | None = ...,
                currency: builtins.str | None = ...,
                paymentStatus: global___Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType | None = ...,
                extendedContentMessage: waArmadilloXMA.WAArmadilloXMA_pb2.ExtendedContentMessage | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["amount", b"amount", "currency", b"currency", "extendedContentMessage", b"extendedContentMessage", "paymentStatus", b"paymentStatus", "transactionID", b"transactionID"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["amount", b"amount", "currency", b"currency", "extendedContentMessage", b"extendedContentMessage", "paymentStatus", b"paymentStatus", "transactionID", b"transactionID"]) -> None: ...

        @typing.final
        class NetworkVerificationMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            CODETEXT_FIELD_NUMBER: builtins.int
            codeText: builtins.str
            def __init__(
                self,
                *,
                codeText: builtins.str | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["codeText", b"codeText"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["codeText", b"codeText"]) -> None: ...

        @typing.final
        class NoteReplyMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            TEXTCONTENT_FIELD_NUMBER: builtins.int
            STICKERCONTENT_FIELD_NUMBER: builtins.int
            VIDEOCONTENT_FIELD_NUMBER: builtins.int
            NOTEID_FIELD_NUMBER: builtins.int
            NOTETEXT_FIELD_NUMBER: builtins.int
            NOTETIMESTAMPMS_FIELD_NUMBER: builtins.int
            noteID: builtins.str
            noteTimestampMS: builtins.int
            @property
            def textContent(self) -> waCommon.WACommon_pb2.MessageText: ...
            @property
            def stickerContent(self) -> waCommon.WACommon_pb2.SubProtocol: ...
            @property
            def videoContent(self) -> waCommon.WACommon_pb2.SubProtocol: ...
            @property
            def noteText(self) -> waCommon.WACommon_pb2.MessageText: ...
            def __init__(
                self,
                *,
                textContent: waCommon.WACommon_pb2.MessageText | None = ...,
                stickerContent: waCommon.WACommon_pb2.SubProtocol | None = ...,
                videoContent: waCommon.WACommon_pb2.SubProtocol | None = ...,
                noteID: builtins.str | None = ...,
                noteText: waCommon.WACommon_pb2.MessageText | None = ...,
                noteTimestampMS: builtins.int | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["noteID", b"noteID", "noteReplyContent", b"noteReplyContent", "noteText", b"noteText", "noteTimestampMS", b"noteTimestampMS", "stickerContent", b"stickerContent", "textContent", b"textContent", "videoContent", b"videoContent"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["noteID", b"noteID", "noteReplyContent", b"noteReplyContent", "noteText", b"noteText", "noteTimestampMS", b"noteTimestampMS", "stickerContent", b"stickerContent", "textContent", b"textContent", "videoContent", b"videoContent"]) -> None: ...
            def WhichOneof(self, oneof_group: typing.Literal["noteReplyContent", b"noteReplyContent"]) -> typing.Literal["textContent", "stickerContent", "videoContent"] | None: ...

        @typing.final
        class BumpExistingMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            @property
            def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
            def __init__(
                self,
                *,
                key: waCommon.WACommon_pb2.MessageKey | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["key", b"key"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["key", b"key"]) -> None: ...

        @typing.final
        class ImageGalleryMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            IMAGES_FIELD_NUMBER: builtins.int
            @property
            def images(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[waCommon.WACommon_pb2.SubProtocol]: ...
            def __init__(
                self,
                *,
                images: collections.abc.Iterable[waCommon.WACommon_pb2.SubProtocol] | None = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["images", b"images"]) -> None: ...

        @typing.final
        class ScreenshotAction(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _ScreenshotType:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _ScreenshotTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Armadillo.Content.ScreenshotAction._ScreenshotType.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                SCREENSHOT_IMAGE: Armadillo.Content.ScreenshotAction._ScreenshotType.ValueType  # 1
                SCREEN_RECORDING: Armadillo.Content.ScreenshotAction._ScreenshotType.ValueType  # 2

            class ScreenshotType(_ScreenshotType, metaclass=_ScreenshotTypeEnumTypeWrapper): ...
            SCREENSHOT_IMAGE: Armadillo.Content.ScreenshotAction.ScreenshotType.ValueType  # 1
            SCREEN_RECORDING: Armadillo.Content.ScreenshotAction.ScreenshotType.ValueType  # 2

            SCREENSHOTTYPE_FIELD_NUMBER: builtins.int
            screenshotType: global___Armadillo.Content.ScreenshotAction.ScreenshotType.ValueType
            def __init__(
                self,
                *,
                screenshotType: global___Armadillo.Content.ScreenshotAction.ScreenshotType.ValueType | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["screenshotType", b"screenshotType"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["screenshotType", b"screenshotType"]) -> None: ...

        @typing.final
        class ExtendedContentMessageWithSear(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            SEARID_FIELD_NUMBER: builtins.int
            PAYLOAD_FIELD_NUMBER: builtins.int
            NATIVEURL_FIELD_NUMBER: builtins.int
            SEARASSOCIATEDMESSAGE_FIELD_NUMBER: builtins.int
            SEARSENTWITHMESSAGEID_FIELD_NUMBER: builtins.int
            searID: builtins.str
            payload: builtins.bytes
            nativeURL: builtins.str
            searSentWithMessageID: builtins.str
            @property
            def searAssociatedMessage(self) -> waCommon.WACommon_pb2.SubProtocol: ...
            def __init__(
                self,
                *,
                searID: builtins.str | None = ...,
                payload: builtins.bytes | None = ...,
                nativeURL: builtins.str | None = ...,
                searAssociatedMessage: waCommon.WACommon_pb2.SubProtocol | None = ...,
                searSentWithMessageID: builtins.str | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["nativeURL", b"nativeURL", "payload", b"payload", "searAssociatedMessage", b"searAssociatedMessage", "searID", b"searID", "searSentWithMessageID", b"searSentWithMessageID"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["nativeURL", b"nativeURL", "payload", b"payload", "searAssociatedMessage", b"searAssociatedMessage", "searID", b"searID", "searSentWithMessageID", b"searSentWithMessageID"]) -> None: ...

        @typing.final
        class RavenActionNotifMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _ActionType:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _ActionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Armadillo.Content.RavenActionNotifMessage._ActionType.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                PLAYED: Armadillo.Content.RavenActionNotifMessage._ActionType.ValueType  # 0
                SCREENSHOT: Armadillo.Content.RavenActionNotifMessage._ActionType.ValueType  # 1
                FORCE_DISABLE: Armadillo.Content.RavenActionNotifMessage._ActionType.ValueType  # 2

            class ActionType(_ActionType, metaclass=_ActionTypeEnumTypeWrapper): ...
            PLAYED: Armadillo.Content.RavenActionNotifMessage.ActionType.ValueType  # 0
            SCREENSHOT: Armadillo.Content.RavenActionNotifMessage.ActionType.ValueType  # 1
            FORCE_DISABLE: Armadillo.Content.RavenActionNotifMessage.ActionType.ValueType  # 2

            KEY_FIELD_NUMBER: builtins.int
            ACTIONTIMESTAMP_FIELD_NUMBER: builtins.int
            ACTIONTYPE_FIELD_NUMBER: builtins.int
            actionTimestamp: builtins.int
            actionType: global___Armadillo.Content.RavenActionNotifMessage.ActionType.ValueType
            @property
            def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
            def __init__(
                self,
                *,
                key: waCommon.WACommon_pb2.MessageKey | None = ...,
                actionTimestamp: builtins.int | None = ...,
                actionType: global___Armadillo.Content.RavenActionNotifMessage.ActionType.ValueType | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["actionTimestamp", b"actionTimestamp", "actionType", b"actionType", "key", b"key"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["actionTimestamp", b"actionTimestamp", "actionType", b"actionType", "key", b"key"]) -> None: ...

        @typing.final
        class RavenMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _EphemeralType:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _EphemeralTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Armadillo.Content.RavenMessage._EphemeralType.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                VIEW_ONCE: Armadillo.Content.RavenMessage._EphemeralType.ValueType  # 0
                ALLOW_REPLAY: Armadillo.Content.RavenMessage._EphemeralType.ValueType  # 1
                KEEP_IN_CHAT: Armadillo.Content.RavenMessage._EphemeralType.ValueType  # 2

            class EphemeralType(_EphemeralType, metaclass=_EphemeralTypeEnumTypeWrapper): ...
            VIEW_ONCE: Armadillo.Content.RavenMessage.EphemeralType.ValueType  # 0
            ALLOW_REPLAY: Armadillo.Content.RavenMessage.EphemeralType.ValueType  # 1
            KEEP_IN_CHAT: Armadillo.Content.RavenMessage.EphemeralType.ValueType  # 2

            IMAGEMESSAGE_FIELD_NUMBER: builtins.int
            VIDEOMESSAGE_FIELD_NUMBER: builtins.int
            EPHEMERALTYPE_FIELD_NUMBER: builtins.int
            ephemeralType: global___Armadillo.Content.RavenMessage.EphemeralType.ValueType
            @property
            def imageMessage(self) -> waCommon.WACommon_pb2.SubProtocol: ...
            @property
            def videoMessage(self) -> waCommon.WACommon_pb2.SubProtocol: ...
            def __init__(
                self,
                *,
                imageMessage: waCommon.WACommon_pb2.SubProtocol | None = ...,
                videoMessage: waCommon.WACommon_pb2.SubProtocol | None = ...,
                ephemeralType: global___Armadillo.Content.RavenMessage.EphemeralType.ValueType | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["ephemeralType", b"ephemeralType", "imageMessage", b"imageMessage", "mediaContent", b"mediaContent", "videoMessage", b"videoMessage"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["ephemeralType", b"ephemeralType", "imageMessage", b"imageMessage", "mediaContent", b"mediaContent", "videoMessage", b"videoMessage"]) -> None: ...
            def WhichOneof(self, oneof_group: typing.Literal["mediaContent", b"mediaContent"]) -> typing.Literal["imageMessage", "videoMessage"] | None: ...

        @typing.final
        class CommonSticker(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _StickerType:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _StickerTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Armadillo.Content.CommonSticker._StickerType.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                SMALL_LIKE: Armadillo.Content.CommonSticker._StickerType.ValueType  # 1
                MEDIUM_LIKE: Armadillo.Content.CommonSticker._StickerType.ValueType  # 2
                LARGE_LIKE: Armadillo.Content.CommonSticker._StickerType.ValueType  # 3

            class StickerType(_StickerType, metaclass=_StickerTypeEnumTypeWrapper): ...
            SMALL_LIKE: Armadillo.Content.CommonSticker.StickerType.ValueType  # 1
            MEDIUM_LIKE: Armadillo.Content.CommonSticker.StickerType.ValueType  # 2
            LARGE_LIKE: Armadillo.Content.CommonSticker.StickerType.ValueType  # 3

            STICKERTYPE_FIELD_NUMBER: builtins.int
            stickerType: global___Armadillo.Content.CommonSticker.StickerType.ValueType
            def __init__(
                self,
                *,
                stickerType: global___Armadillo.Content.CommonSticker.StickerType.ValueType | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["stickerType", b"stickerType"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["stickerType", b"stickerType"]) -> None: ...

        COMMONSTICKER_FIELD_NUMBER: builtins.int
        SCREENSHOTACTION_FIELD_NUMBER: builtins.int
        EXTENDEDCONTENTMESSAGE_FIELD_NUMBER: builtins.int
        RAVENMESSAGE_FIELD_NUMBER: builtins.int
        RAVENACTIONNOTIFMESSAGE_FIELD_NUMBER: builtins.int
        EXTENDEDMESSAGECONTENTWITHSEAR_FIELD_NUMBER: builtins.int
        IMAGEGALLERYMESSAGE_FIELD_NUMBER: builtins.int
        PAYMENTSTRANSACTIONMESSAGE_FIELD_NUMBER: builtins.int
        BUMPEXISTINGMESSAGE_FIELD_NUMBER: builtins.int
        NOTEREPLYMESSAGE_FIELD_NUMBER: builtins.int
        RAVENMESSAGEMSGR_FIELD_NUMBER: builtins.int
        NETWORKVERIFICATIONMESSAGE_FIELD_NUMBER: builtins.int
        @property
        def commonSticker(self) -> global___Armadillo.Content.CommonSticker: ...
        @property
        def screenshotAction(self) -> global___Armadillo.Content.ScreenshotAction: ...
        @property
        def extendedContentMessage(self) -> waArmadilloXMA.WAArmadilloXMA_pb2.ExtendedContentMessage: ...
        @property
        def ravenMessage(self) -> global___Armadillo.Content.RavenMessage: ...
        @property
        def ravenActionNotifMessage(self) -> global___Armadillo.Content.RavenActionNotifMessage: ...
        @property
        def extendedMessageContentWithSear(self) -> global___Armadillo.Content.ExtendedContentMessageWithSear: ...
        @property
        def imageGalleryMessage(self) -> global___Armadillo.Content.ImageGalleryMessage: ...
        @property
        def paymentsTransactionMessage(self) -> global___Armadillo.Content.PaymentsTransactionMessage: ...
        @property
        def bumpExistingMessage(self) -> global___Armadillo.Content.BumpExistingMessage: ...
        @property
        def noteReplyMessage(self) -> global___Armadillo.Content.NoteReplyMessage: ...
        @property
        def ravenMessageMsgr(self) -> global___Armadillo.Content.RavenMessage: ...
        @property
        def networkVerificationMessage(self) -> global___Armadillo.Content.NetworkVerificationMessage: ...
        def __init__(
            self,
            *,
            commonSticker: global___Armadillo.Content.CommonSticker | None = ...,
            screenshotAction: global___Armadillo.Content.ScreenshotAction | None = ...,
            extendedContentMessage: waArmadilloXMA.WAArmadilloXMA_pb2.ExtendedContentMessage | None = ...,
            ravenMessage: global___Armadillo.Content.RavenMessage | None = ...,
            ravenActionNotifMessage: global___Armadillo.Content.RavenActionNotifMessage | None = ...,
            extendedMessageContentWithSear: global___Armadillo.Content.ExtendedContentMessageWithSear | None = ...,
            imageGalleryMessage: global___Armadillo.Content.ImageGalleryMessage | None = ...,
            paymentsTransactionMessage: global___Armadillo.Content.PaymentsTransactionMessage | None = ...,
            bumpExistingMessage: global___Armadillo.Content.BumpExistingMessage | None = ...,
            noteReplyMessage: global___Armadillo.Content.NoteReplyMessage | None = ...,
            ravenMessageMsgr: global___Armadillo.Content.RavenMessage | None = ...,
            networkVerificationMessage: global___Armadillo.Content.NetworkVerificationMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["bumpExistingMessage", b"bumpExistingMessage", "commonSticker", b"commonSticker", "content", b"content", "extendedContentMessage", b"extendedContentMessage", "extendedMessageContentWithSear", b"extendedMessageContentWithSear", "imageGalleryMessage", b"imageGalleryMessage", "networkVerificationMessage", b"networkVerificationMessage", "noteReplyMessage", b"noteReplyMessage", "paymentsTransactionMessage", b"paymentsTransactionMessage", "ravenActionNotifMessage", b"ravenActionNotifMessage", "ravenMessage", b"ravenMessage", "ravenMessageMsgr", b"ravenMessageMsgr", "screenshotAction", b"screenshotAction"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["bumpExistingMessage", b"bumpExistingMessage", "commonSticker", b"commonSticker", "content", b"content", "extendedContentMessage", b"extendedContentMessage", "extendedMessageContentWithSear", b"extendedMessageContentWithSear", "imageGalleryMessage", b"imageGalleryMessage", "networkVerificationMessage", b"networkVerificationMessage", "noteReplyMessage", b"noteReplyMessage", "paymentsTransactionMessage", b"paymentsTransactionMessage", "ravenActionNotifMessage", b"ravenActionNotifMessage", "ravenMessage", b"ravenMessage", "ravenMessageMsgr", b"ravenMessageMsgr", "screenshotAction", b"screenshotAction"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["content", b"content"]) -> typing.Literal["commonSticker", "screenshotAction", "extendedContentMessage", "ravenMessage", "ravenActionNotifMessage", "extendedMessageContentWithSear", "imageGalleryMessage", "paymentsTransactionMessage", "bumpExistingMessage", "noteReplyMessage", "ravenMessageMsgr", "networkVerificationMessage"] | None: ...

    PAYLOAD_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def payload(self) -> global___Armadillo.Payload: ...
    @property
    def metadata(self) -> global___Armadillo.Metadata: ...
    def __init__(
        self,
        *,
        payload: global___Armadillo.Payload | None = ...,
        metadata: global___Armadillo.Metadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["metadata", b"metadata", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["metadata", b"metadata", "payload", b"payload"]) -> None: ...

global___Armadillo = Armadillo
